**********************************************
* Calculate transition matrix for
* 
* 611700 -> 611602
* 611701 -> 611602 611601
* 611702 -> 611602 611601
*
* This is a special case because we have duplicate splits (611701 & 611702)
* and so we need additional information in order to determine the system.
*
* Note that the split above has been coded in reverse: in reality, as we move 
* from Q2 2015 to Q3 2015, the the total of 2 circles becomes 3 circles 
******************************************************************


set trace off
set more off

mata

M0 = 0, 0, 0\ 1, 1, 1
M0

M = 0, 1, 0, 0, 0, 1\ 0, -1, 0, 0, 0, -1
M
end

local y 2015
local q 3

local y2 2015
local q2 2

local type t

global circles "611700, 611701, 611702"

use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y' Q`q'/FY`y' Q`q'.dta", clear
keep circle_id net_dem_`type'
keep if inlist(circle_id, ${circles})

order circle_id net_dem_`type'
rename circle_id q`q'_`y'_circle_id
duplicates drop

sort q`q'_`y'_circle_id 
list
keep net_dem_`type'

*Make sure we have everyone
qui count
*assert `r(N)' == `n'

mata : a = st_data(., 1)

* Get "b" vector -- list of ending current net demand
use "Data/Cleaned Data/Administrative Data/Punjab Compiled - Quarterly.dta", clear

keep if fyear == `y2' & qtr == `q2'
rename circle_id q`q2'_`y2'_circle_id
duplicates drop

keep if inlist(q`q2'_`y2'_circle_id, 611601, 611602)
sort q`q2'_`y2'_circle_id
list
keep net_dem_`type'
	
*Make sure we have everyone
qui count
*assert `r(N)' == `m'

mata : b = st_data(., 1)

// Assign transition matrix; solve if necessary
mata : calculateT(3, 2, M0, M, a, b, T=.)


mata : T
mata : st_matrix("T", T)
svmat T
drop net_dem*


save "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To TP Randomization/FY2015 Q3/rp315_t.dta", replace
