**********************************************
* Calculate transition matrix for
* 
* 611601 -> 611701 611702
* 611602 -> 611700 611701 611702
*
* This is a special case because we have duplicate splits (611701 & 611702)
* and so we need additional information in order to determine the system.
*
* Takes place from Q2 2015 to Q3 2015
******************************************************************

set trace off
set more off

mata

M0 = 0, 1\0.24, 0\0.76, 0
M0

M = 0, 0, 0, -1.53\0, 0, 0, 1\0, 0, 0, .53
M
end

local y 2015
local q 2

local y2 2015
local q2 3

local type t

global circles "611601, 611602"

use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y' Q`q'/FY`y' Q`q'.dta", clear
keep circle_id net_dem_`type'
keep if inlist(circle_id, ${circles})

order circle_id net_dem_`type'
rename circle_id q`q'_`y'_circle_id
duplicates drop

sort q`q'_`y'_circle_id 
list
keep net_dem_`type'

*Make sure we have everyone
qui count
*assert `r(N)' == `n'

mata : a = st_data(., 1)

* Get "b" vector -- list of ending current net demand
use "Data/Cleaned Data/Administrative Data/Punjab Compiled - Quarterly.dta", clear

keep if fyear == `y2' & qtr == `q2'
rename circle_id q`q2'_`y2'_circle_id
duplicates drop

keep if inlist(q`q2'_`y2'_circle_id, 611700, 611701, 611702)
sort q`q2'_`y2'_circle_id
list
keep net_dem_`type'
	
*Make sure we have everyone
qui count
*assert `r(N)' == `m'

mata : b = st_data(., 1)

// Assign transition matrix; solve if necessary
mata : calculateT(2, 2, M0, M, a, b, T=.)

mata : T
mata : st_matrix("T", T)
svmat T
drop net_dem*


save "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Present/FY2015 Q2/rp315_t.dta", replace
