* Preference Data Analysis
* Obeid
* 15th August 2013

* Updated 5 June 2015 by Kunal Mangal, pulled from 130815 Preference Data Analysis
**********************************************************************************

****************************************************
* I.   Workspace
* II.  Data Cleaning & Checks
* III. Saving
****************************************************


* I.  Workspace
********************

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

*******************************************************

*** Lahore Non-Pilot Preferences ***
foreach X of numlist 2/15{
	insheet using "Data/Raw Data/Preference Data/Year 1/Lahore/130731 Lahore Transfers MAIN Randomization 1170000 GROUP `X'.csv" , comma clear
	destring own_circle ranking hr_id,force replace
	tempfile `X'
	sa ``X''
}

*** Lahore Pilot Preferences ***
u "Data/Raw Data/Preference Data/Year 1/Pilot/130728 Lahore Pilot Preferences.dta", clear
drop group
rename hr_id own_hr_id
gen group=1
keep  own_hr_id division_name circle_name circle_id ranking own_circle group
	preserve // Adding hr_id
	gen hr_id=own_hr_id if own_circle==1
	keep circle_id hr_id
	drop if hr_id==.
	tempfile hr_id
	sa `hr_id'
	restore
merge m:1 circle_id using `hr_id'
drop _merge
tempfile 1
sa `1'

*** Multan Pilot Preferences ***
import excel "Data/Raw Data/Preference Data/Year 1/Pilot/Multan Pilot Preference Data.xlsx", sheet("Stacked Data") firstrow clear
replace group = "1"
destring group,replace
tempfile multan
sa `multan'

*** Non Lahore Pilot Preferences ***
foreach division in BAHAWALPUR RAWALPINDI GUJRANWALA FAISALABAD MULTAN SARGODHA{
	if "`division'" == "BAHAWALPUR" | "`division'" == "RAWALPINDI"{
		foreach group of numlist 1/4 {
		import excel "Data/Raw Data/Preference Data/Year 1/Non-Lahore/130813 Non-Lahore Transfers MAIN Randomization 606 `division' GROUP `group'.xls", sheet("Sheet1") firstrow clear
		di "`division'" "`group'"
		cap rename Own_circle own_circle
		cap rename Own_Circle own_circle
		cap rename OwnCircle own_circle
		cap rename Ranking ranking
		cap rename  Additional_charge Additional_Charge
		cap rename  AdditionalCharge Additional_Charge
		cap rename  Additiional_Charge Additional_Charge
		cap rename Inspector_Change Inspector_change
		cap rename InspectorChange Inspector_change
		cap rename hr_full_name hr_name
		tempfile `division'`group'
		sa ``division'`group''
		}
	}

	else if "`division'" == "GUJRANWALA" | "`division'" == "FAISALABAD" {
		foreach group of numlist 1/6 {
		import excel "Data/Raw Data/Preference Data/Year 1/Non-Lahore/130813 Non-Lahore Transfers MAIN Randomization 606 `division' GROUP `group'.xls", sheet("Sheet1") firstrow clear
		di "`division'" "`group'"
		cap rename Own_circle own_circle
		cap rename Own_Circle own_circle
		cap rename OwnCircle own_circle
		cap rename Ranking ranking
		cap rename  Additional_charge Additional_Charge
		cap rename  AdditionalCharge Additional_Charge
		cap rename  Additiional_Charge Additional_Charge
		cap rename Inspector_Change Inspector_change
		cap rename InspectorChange Inspector_change
		cap rename hr_full_name hr_name
		tempfile `division'`group'
		sa ``division'`group''
		}
	}

	else if "`division'" == "MULTAN" {
		foreach group of numlist 2/6 {
		import excel "Data/Raw Data/Preference Data/Year 1/Non-Lahore/130813 Non-Lahore Transfers MAIN Randomization 606 `division' GROUP `group'.xls", sheet("Sheet1") firstrow clear
		di "`division'" "`group'"
		cap rename Own_circle own_circle
		cap rename Own_Circle own_circle
		cap rename OwnCircle own_circle
		cap rename Ranking ranking
		cap rename  Additional_charge Additional_Charge
		cap rename  AdditionalCharge Additional_Charge
		cap rename  Additiional_Charge Additional_Charge
		cap rename Inspector_Change Inspector_change
		cap rename InspectorChange Inspector_change
		cap rename hr_full_name hr_name
		tempfile `division'`group'
		sa ``division'`group''
		}
	}
	
	else if "`division'" == "SARGODHA" {
		foreach group of numlist 1/2 {
		import excel "Data/Raw Data/Preference Data/Year 1/Non-Lahore/130813 Non-Lahore Transfers MAIN Randomization 606 `division' GROUP `group'.xls", sheet("Sheet1") firstrow clear
		di "`division'" "`group'"
		cap rename Own_circle own_circle
		cap rename Own_Circle own_circle
		cap rename OwnCircle own_circle
		cap rename Ranking ranking
		cap rename  Additional_charge Additional_Charge
		cap rename  AdditionalCharge Additional_Charge
		cap rename  Additiional_Charge Additional_Charge
		cap rename Inspector_Change Inspector_change
		cap rename InspectorChange Inspector_change
		cap rename hr_full_name hr_name
		tempfile `division'`group'
		sa ``division'`group''
		}
	}
}


*** Appending Together ***
u `1',clear
foreach Y of numlist 2/15{
	append using ``Y''
}
append using `multan'
foreach division in BAHAWALPUR RAWALPINDI GUJRANWALA FAISALABAD MULTAN SARGODHA{
	if "`division'" == "BAHAWALPUR" | "`division'" == "RAWALPINDI"{
		foreach group of numlist 1/4 {
		append using ``division'`group''
		}
	}
	else if "`division'" == "GUJRANWALA" | "`division'" == "FAISALABAD" {
		foreach group of numlist 1/6 {
		append using ``division'`group''
		}
	}
	else if "`division'" == "MULTAN" {
		foreach group of numlist 2/6 {
		append using ``division'`group''
		}
	}
	else if "`division'" == "SARGODHA" {
		foreach group of numlist 1/2 {
		append using ``division'`group''
		}
	}
}



drop N-R
drop if division_name==""
drop if circle_name==""
gen partition_name=division_name
replace partition_name="LAHORE" if inlist(division_name,"LAHORE A","LAHORE B")
replace own_circle = 0 if own_circle == .

		

** Adding Treatment Status **
gen treatment=0 //hardcoding this in
replace treatment=1 if inlist(group,1,5,7,9,13) & inlist(division_name,"LAHORE A","LAHORE B") 
replace treatment=1 if inlist(group,3,4) & inlist(division_name,"BAHAWALPUR")
replace treatment=1 if inlist(group,1,3,5) & inlist(division_name,"MULTAN")
replace treatment=1 if inlist(group,4,6) & inlist(division_name,"FAISALABAD")
replace treatment=1 if inlist(group,1) & inlist(division_name,"SARGODHA")
replace treatment=1 if inlist(group,3,4) & inlist(division_name,"RAWALPINDI") 
replace treatment=1 if inlist(group,1,5) & inlist(division_name,"GUJRANWALA")


****************************************************
*
* II. Data Cleaning & Checks
*
****************************************************
// Need to clean own_hr_id. Fix me
/*replace hr_id = 111 if hr_name=="M. RIAZ GUJJAR"
replace hr_id = 50500 if hr_id==50456 // Fix Me
replace own_hr_id = 50500 if own_hr_id==50456 // Fix Me
*/

//assert fails as 5 guys need 
assert own_hr_id == hr_id if own_circle==1 & treatment==1
//assert own_circle==1 if own_hr_id == hr_id & treatment==1   This assert fails because of additional charge issues

sort partition_name group own_hr_id own_circle_name ranking
bys partition_name group own_hr_id own_circle_name: gen rankingcheck=_n
assert rankingcheck == ranking if ranking!=.
drop rankingcheck

* Fix some typos in additional charges
replace Additional_Charge = 0 if hr_id == 11509
replace Additional_Charge = 0 if hr_id == 40813
replace Additional_Charge = 0 if hr_id == 112531
replace Additional_Charge = 0 if hr_id == 81110 

* Fix some missing values
replace own_hr_id = 33000 if own_hr_full_name == "Zafar Iqbal" & own_hr_id == .

* Drop vacant circles
*drop if own_hr_full_name == "VACANT"

****************************************************
*
* III. Saving
*
****************************************************

order division_name partition_name group treatment district own_hr_id own_hr_full_name own_circle_name  circle_id circle_name hr_id hr_name ranking own_circle
sort partition_name group own_hr_id own_circle_name ranking

save "Data/Cleaned Data/Preference Data/150605 Compiled Preference Data.dta", replace

* Fix some crosswalking values
replace circle_id = 800513 if circle_id == 800512

save "Data/Cleaned Data/Preference Data/Compiled Preference Data.dta", replace
