********************************************************************
* Calculate Inspector Ranks - Q4 - Demand - LAHORE

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

********************************************************************

********************************************************************
* 1. Calculate Inspector HR
* a. Get a list of inspectors in the program, handle additional charges
* b. Drop inspector in litigated circle
* c. Calculate the fraction of time they 
*    were in each circle, so that we can pro-rate performance
********************************************************************

insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
keep if fyear == 2014 & qtr == 4
keep circle_id
tempfile litigation
save `litigation'

* Get a list of inspectors in the program
use "Data\Raw Data\Current HR Confirmation/131124 Stage II Treatment Staff", clear

* Fix division_id problem
replace division_id = 5 if division_id == 6

* Fix XXV Part 1 and XXV Part 2 confusion
replace circle_id = 402800 if hr_id == 40838

// Drop the additional charge for inspectors that were ballotted on both main and additional charge
bys division_id hr_id : gen charge_count = _N
gen balloted_ac = ins_1_ac == 1 & charge_count == 1 // balloted_ac = 1 if inspector only balloted on additional charge

drop if ins_1_ac ==1 & charge_count > 1
drop charge_count

// Drop inspector in circle under litigation
merge 1:1 circle_id using `litigation'
drop if _merge == 2
drop if _merge == 3 // 0 circles under litigation
drop _merge

rename circle_id balloted_circle_id

keep division_id division_name district hr_id ins_1 group balloted_circle_id ranking_method balloted_ac ranking_method
isid hr_id

keep if ranking_method == "DEMAND"

tempfile inspectors
save `inspectors'


* Use HR data to evaluate time in circle
import excel using "Data\Raw Data\Current HR Confirmation/140630 HR Verification FY2014 Q4\140717 HR Verification Q4.xlsx", first clear

drop hr_id3 - BL

// Data checks
*assert circle_id != .
drop if circle_id == . 	// 2 circles / inspectors + 1 blank row

assert hr_id1 != . if ins1 != "" & ins1 != "VACANT"
// 2 contradictions, VACANT circles, OK

assert hr_id2 != . if ins2 != "" & ins2 != "VACANT"

tostring start1, replace
replace start1 = "" if start1  == "."

gen qtr = 4

tempfile hr4
save `hr4'


import excel using "Data\Raw Data\Current HR Confirmation/140414 HR Verification FY2014 Q2-Q3\140709 HR Verification Q3 Inspectors.xlsx", first clear

// Data checks
assert circle_id != .

assert hr_id1 != . if ins1 != "" & ins1 != "VACANT" 
assert hr_id2 != . if ins2 != "" & ins2 != "VACANT"
assert hr_id3 != . if ins3 != "" & ins3 != "VACANT"

gen qtr = 3

tempfile hr3
save `hr3'

import excel using "Data\Raw Data\Current HR Confirmation/140414 HR Verification FY2014 Q2-Q3\140709 HR Verification Q2 Inspectors.xlsx", first clear

// Data checks
assert circle_id != .

assert hr_id1 != . if ins1 != "" & ins1 != "VACANT" 
assert hr_id2 != . if ins2 != "" & ins2 != "VACANT"
assert hr_id3 != . if ins3 != "" & ins3 != "VACANT"

gen qtr = 2

tempfile hr2
save `hr2'

import excel using "Data\Raw Data\Current HR Confirmation/131028 HR Verification FY2014Q1\140709 HR Verification Q1 Inspectors.xlsx", first clear

// Data checks
assert circle_id != .

assert hr_id1 != . if ins1 != "" & ins1 != "VACANT" 
assert hr_id2 != . if ins2 != "" & ins2 != "VACANT"

gen qtr = 1

tempfile hr1
save `hr1'

* Make sure there's continuity between quarters
* Q1 / Q2
use `hr1', clear
keep if inspector == 1

keep circle_id ins* hr_id* start* end*
tostring end*, replace

reshape long ins hr_id start end, i(circle_id) j(j)
drop if hr_id == .
egen maxj = max(j), by(circle_id)
keep if j == maxj

rename hr_id hr_id1
gen qtr = 1

merge 1:1 circle_id hr_id1 using `hr2'
drop if inspector == 2

assert _merge == 3 if end == "" & qtr == 1 & !inlist(circle_id, 614000, 613610, 613900, 614200, 614300)
* Excepting the messy property transfer

* Q2/Q3
use `hr2', clear
keep if inspector == 1

keep circle_id ins* hr_id* start* end*
tostring end*, replace

reshape long ins hr_id start end, i(circle_id) j(j)
drop if hr_id == .
egen maxj = max(j), by(circle_id)
keep if j == maxj

rename hr_id hr_id1
gen qtr = 2

merge 1:1 circle_id hr_id1 using `hr3'
drop if inspector == 2

assert _merge == 3 if end == "" & qtr == 2 & !inlist(circle_id, 200200, 200301, 409500, 507201)
// 4 contradictions OK -- 200200 & 200301, circles merge, and 409500 and 507201 circle split


* Q3/Q4
use `hr3', clear
keep if inspector == 1

keep circle_id ins* hr_id* start* end*
tostring end*, replace

reshape long ins hr_id start end, i(circle_id) j(j)
drop if hr_id == .
egen maxj = max(j), by(circle_id)
keep if j == maxj

rename hr_id hr_id1
gen qtr = 3

merge 1:1 circle_id hr_id1 using `hr4'
drop if inspector == 2

assert _merge == 3 if end == "" & qtr == 3 & !inlist(circle_id, 901301, 901302)
// 2 contradictions OK -- 901301 and 901302 merge

* Check additional charges
// Want to check that if an inspector is in two circles at 1 time
// then the ins_ac field is filled

*Q1
use `hr1', clear
keep if inspector == 1

tostring end*, replace

reshape long hr_id ins ins_ac start end, i(circle_id) j(j)
drop if hr_id == .

replace start = "1.7.2013" if start == ""
replace end = "30.9.2013" if end == ""

foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}

local s = mdy(7,1,2013)
local e = mdy(9, 30, 2013)

gen flag = .

forval i = `s' / `e' {
	gen in_interval = `i' >= start & `i' <= `e'
	egen in_interval_all = total(in_interval), by(hr_id)
	
	replace flag = 1 if ins_ac == . & in_interval_all > 1
	drop in_interval in_interval_all
}

assert flag == .

*Q2
use `hr2', clear
keep if inspector == 1

tostring end*, replace

reshape long hr_id ins ins_ac start end, i(circle_id) j(j)
drop if hr_id == .

replace start = "1.10.2013" if start == ""
replace end = "31.12.2013" if end == ""

foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}

local s = mdy(10,1,2013)
local e = mdy(12, 31, 2013)

gen flag = .

forval i = `s' / `e' {
	gen in_interval = `i' >= start & `i' <= `e'
	egen in_interval_all = total(in_interval), by(hr_id)
	
	replace flag = 1 if ins_ac == . & in_interval_all > 1
	drop in_interval in_interval_all
}

assert flag == .


*Q3
use `hr3', clear
keep if inspector == 1

tostring end*, replace

reshape long hr_id ins ins_ac start end, i(circle_id) j(j)
drop if hr_id == .

replace start = "1.1.2014" if start == ""
replace end = "31.3.2014" if end == ""

foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}

local s = mdy(1,1,2014)
local e = mdy(3, 31, 2014)

gen flag = .

forval i = `s' / `e' {
	gen in_interval = `i' >= start & `i' <= `e'
	egen in_interval_all = total(in_interval), by(hr_id)
	
	replace flag = 1 if ins_ac == . & in_interval_all > 1
	drop in_interval in_interval_all
}

assert flag == .

*Q4
use `hr4', clear
keep if inspector == 1

tostring start1 end*, replace

reshape long hr_id ins ins_ac start end, i(circle_id) j(j)
drop if hr_id == .

replace start = "1.4.2014" if start == ""
replace end = "30.6.2014" if end == ""

foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}

local s = mdy(4,1,2014)
local e = mdy(6, 30, 2014)

gen flag = .

forval i = `s' / `e' {
	gen in_interval = `i' >= start & `i' <= `e'
	egen in_interval_all = total(in_interval), by(hr_id)
	
	replace flag = 1 if ins_ac == . & in_interval_all > 1
	drop in_interval in_interval_all
}

assert flag == .

*********
* Resume

use `hr1', clear
tostring end*, replace

append using `hr2'
append using `hr3'
append using `hr4'

tostring end*, replace

reshape long hr_id ins start end ins_ac, i(circle_id qtr inspector) j(j)
drop ins
drop if hr_id == .

merge m:1 hr_id using `inspectors', keepusing(balloted_circle_id balloted_ac division_id group ranking_method)
drop if _merge == 1
assert _merge != 2
drop _merge

* Make sure that inspectors with an additional charge also have a main charge
bys hr_id qtr : gen circlecount = _N
*assert ins_ac == 0 | ins_ac == . if circlecount == 1 
drop circlecount

// Drop the additional charge for inspectors that were ballotted on both main and additional charge
drop if ins_ac == 1 & balloted_ac != 1

* Prorate time in main charge if lost all additional charges
egen has_ac = total(ins_ac), by(hr_id qtr)
qui levelsof hr_id if has_ac == 0 & balloted_ac == 1, s(",")
*br if inlist(hr_id, `r(levels)')

replace start = "02.09.2013" if hr_id == 11660 & circle_id == 108000 & qtr == 1

gen keepmaincharge = .
replace keepmaincharge = 1 if hr_id == 11660

// Always keep ac if balloted on ac, and main charge if nothing else (within quarter)
drop if ins_ac != 1 & balloted_ac == 1 & keepmaincharge != 1

// Drop non-balloted ac if inspector has more than one ac in the quarter
drop if circle_id != balloted_circle_id & has_ac > 1

drop keepmaincharge has_ac

// Make sure the only additional charges are those that were balloted
assert balloted_ac == 1 if ins_ac == 1

order hr_id, first
sort hr_id circle_id

egen maxj = max(j), by(hr_id qtr)
gen current_circle_temp = circle_id if qtr == 4 & j == maxj
egen current_circle = max(current_circle_temp), by(hr_id)
drop current_circle_temp maxj

// Calculate time in circles
replace start = "" if start == "."
replace end = "" if end == "."

replace start = "1.7.2013" if start == "" & qtr == 1
replace end = "30.9.2013" if end == "" & qtr == 1

replace start = "1.10.2013" if start == "" & qtr == 2
replace end = "31.12.2013" if end == "" & qtr == 2

replace start = "1.1.2014" if start == "" & qtr == 3
replace end = "31.3.2014" if end == "" & qtr == 3

replace start = "1.4.2014" if start == "" & qtr == 4
replace end = "30.6.2014" if end == "" & qtr == 4

foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}

gen days_in_circle = end - start
gen fraction_in_circle = .
replace fraction_in_circle = days_in_circle / 91 if qtr <= 2
replace fraction_in_circle = days_in_circle / 89 if qtr == 3
replace fraction_in_circle = days_in_circle / 90 if qtr == 4

// Calculate total time in circle(s), in case they've left
bys hr_id qtr: egen time_in_circles = total(fraction_in_circle)
assert time_in_circles <= 1

tempfile inspectors2
save `inspectors2'

**********************************************
* 2. Calculate Inspector Performance
**********************************************

// Using Q1 data gathered ahead of time for semester 2 performance
import excel using "Data\Raw Data\Department Correspondence\July Demand 2014/140717 July Data.xlsx", first clear

keep if ranking_method == "DEMAND"
keep circle_id net_dem_c
ren net_dem_c q1_2015_net_dem_c

merge 1:1 circle_id using "Data/Cleaned Data\Administrative Data\Crosswalk\Quarterly\To Present - Analysis\2014_q3_crosswalk.dta"
assert _merge != 1
keep if _merge == 3
drop _merge

keep circle_id q1_2015_* q3_2014_* q1_2014_*

gen delta_net_dem_c = q1_2015_net_dem_c - q3_2014_net_dem_c
gen base_net_dem_c = q1_2014_net_dem_c

keep circle_id delta_net_dem_c base_net_dem_c q1_2015_net_dem_c q3_2014_net_dem_c q1_2014_net_dem_c

gen qtr = 4

tempfile performance4
save `performance4'

drop qtr

gen qtr = 3

tempfile performance3
save `performance3'

use "Data/Cleaned Data\Administrative Data\Crosswalk\Quarterly\To Present - Analysis\2014_q3_crosswalk.dta", clear
keep circle_id q3_2014_* q1_2014_*

gen delta_net_dem_c = q3_2014_net_dem_c - q1_2014_net_dem_c
gen base_net_dem_c  = q1_2014_net_dem_c

keep circle_id delta_net_dem_c base_net_dem_c q3_2014_net_dem_c q1_2014_net_dem_c

gen qtr = 2

tempfile performance2
save `performance2'

drop qtr

* Fix crosswalking problem (Circle V changes ID from 614000 to 614001 in Q2)
replace circle_id = 614000 if circle_id == 613630

gen qtr = 1

append using `performance2'
append using `performance3'
append using `performance4'

merge 1:m circle_id qtr using `inspectors2'
assert _merge != 2
keep if _merge == 3
drop _merge

assert delta_net_dem_c != . if ranking_method == "DEMAND"
assert base_net_dem_c != . if ranking_method == "DEMAND"

drop district  j inspector ins_ac start end

// Keep track of whether inspectors spend time in more than one circle with --circlecount--
preserve
	keep group hr_id circle_id
	duplicates drop
	
	bys group hr_id: gen circle_temp = _n
	egen circlecount = max(circle_temp), by(group hr_id)
	drop circle_temp

	keep group hr_id circlecount
	duplicates drop
	
	tempfile circlecount
	save `circlecount'
restore

merge m:1 group hr_id using `circlecount'
assert _merge == 3
drop _merge

egen total_days_in_circles = total(days_in_circle), by(hr_id)
assert total_days_in_circles <= 361

gen performance = .
replace performance = delta_net_dem_c * days_in_circle / 182 if inlist(qtr, 1, 2)
replace performance = delta_net_dem_c * days_in_circle / 179 if inlist(qtr, 3, 4)

gen benchmark = base_net_dem_c * days_in_circle / 361

* Correct for missing values - performance = . if bench = . and vice versa
replace performance = . if benchmark == .
replace benchmark = . if performance == .

* score or bench will be missing only if all are missing
egen score = total(performance), missing by(hr_id)
egen bench = total(benchmark), missing by(hr_id)

preserve
	keep hr_id circle_id 
	duplicates drop
	
	merge m:1 circle_id using `performance4', keepusing(q1_2015_net_dem_c)
	keep if _merge == 3
	// There are 2 that are dropped here, but they are OK

	drop _merge
	
	ren q1_2015_net_dem_c net_dem
	
	bys hr_id (circle_id) : gen j = _n
	
	reshape wide circle_id net_dem, i(hr_id) j(j)
	
	tempfile circleperform
	save `circleperform'
restore

keep hr_id group score bench balloted_circle_id ranking_method balloted_ac current_circle* circlecount
duplicates drop 

isid hr_id

merge 1:1 hr_id using `inspectors', keepusing(division_id)
keep if _merge == 3
drop _merge

gen final_score = score / bench
replace final_score = final_score * 100

* Drop inspectors who are no longer part of the scheme
preserve
	import excel using "Data\Raw Data\Preference Tracking\140811 Treatment Preference sheet Tracking.xlsx", first clear
	keep hr_id ExcludefromScheme
	duplicates drop
	isid hr_id
	
	tempfile exclusion
	save `exclusion'
restore

merge 1:1 hr_id using `exclusion'
drop if _merge == 2

preserve
	keep if ExcludefromScheme == 1
	drop _merge
	
	duplicates drop
	
	tempfile exclucedinspectors
	save `exclucedinspectors'
restore

drop if ExcludefromScheme == 1
drop _merge


gsort + division_id + group - final_score
by division_id group: gen rank = _n
by division_id group : gen groupcount = _N

* This is a pilot group
drop if division_id == 8 & group == 1

* Not ready yet
*drop if division_id == 1

tempfile rankings
save `rankings'

** DATA FOR THE SMS **

use "Data\Raw Data\Current HR Confirmation\131124 Stage II Treatment Staff", clear
keep hr_id division_name district 
duplicates drop
isid hr_id

merge 1:1 hr_id using `rankings'
assert _merge != 2
keep if _merge == 3
drop _merge

keep division_name district group hr_id final_score rank groupcount circlecount ranking_method
order division_name district group hr_id final_score rank groupcount circlecount ranking_method

merge 1:1 hr_id using `circleperform'
keep if _merge == 3
drop _merge

sort division_name group rank

format net_dem* %12.0f
outsheet using "Data\Cleaned Data\Ranks/140821 Q4 Ranks Demand SMS.csv", comma replace

**********************************************
* 3. Calculate Transfers
**********************************************

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization BAHAWALPUR GROUP 3.xlsx", first clear
tempfile preferences
save `preferences'

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization LAHORE GROUP 7.xlsx", first clear
append using `preferences'
save `preferences', replace

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization LAHORE GROUP 13.xlsx", first clear
append using `preferences'
save `preferences', replace

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization FAISALABAD GROUP 6.xlsx", first clear
append using `preferences'
save `preferences', replace

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization GUJRANWALA GROUP 1.xlsx", first clear
append using `preferences'
save `preferences', replace

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization MULTAN GROUP 3.xlsx", first clear
append using `preferences'
save `preferences', replace

import excel using "Data\Raw Data\Preference Tracking\Data\140815 Treated Groups Year 2 Randomization RAWALPINDI GROUP 3.xlsx", first clear
append using `preferences'
save `preferences', replace

ren hr_id circle_hr_id
ren own_hr_id hr_id

drop K entry_date

merge m:1 hr_id using `exclusion'
drop if _merge == 2
drop if ExcludefromScheme == 1
drop _merge

* Additional charges
drop if hr_id == 40912 & ranking == .
drop if hr_id == 40962 & ranking == .

drop if hr_id == 11511 & ranking == .
drop if hr_id == 11671 & ranking == .

assert ranking != .

label define division 1 "BAHAWALPUR" 3 "FAISALABAD" 4 "GUJRANWALA" 5 "LAHORE A" 6 "LAHORE B" 8 "MULTAN" 9 "RAWALPINDI" 11 "SARGODHA"
encode division_name, generate(division_id) label(division)

replace division_id = 5 if division_id == 6

isid division_id group hr_id ranking

rename circle_id preference

keep division_id group hr_id preference ranking
	
// Check that the inspector ranks make sense
bys group hr_id (ranking) : gen rank_check = _n
assert ranking == rank_check
drop rank_check

// Check for duplicates in preferences
duplicates tag group hr_id preference, generate(d)
assert d == 0
drop d

reshape wide preference, i(group hr_id) j(ranking)

merge 1:1 group hr_id using `rankings'
assert _merge == 3
drop _merge

gsort + group - final_score

gen posting = .

forval i = 1/11 {
	gen circle`i' = preference`i'
}

forval i = 1/11 {
	egen next_available = rowfirst(preference*)
	replace posting = next_available if rank == `i'
	drop next_available
	
	gen first = 1 if rank == `i'
	bys division_id group (first) : gen alreadytaken`i' = posting[1]
	drop first
	
	forval j = 1/11 {
		replace preference`j' = . if preference`j' == alreadytaken`i'
	}
}

sort division_id group rank

isid posting

ren balloted_circle_id balloted_circle

* How many transfers?
count
count if balloted_circle != posting


* Up? down? stay the same?
gen balloted_circle_rank = .
forval i = 1/11 {
	replace balloted_circle_rank = `i' if balloted_circle == circle`i'
}

assert balloted_circle_rank != .

gen posting_circle_rank = .
forval i = 1/11 {
	replace posting_circle_rank = `i' if posting == circle`i'
}

assert posting_circle_rank != .

gen diff = posting_circle_rank - balloted_circle_rank

gen movement = diff / abs(diff) if diff != 0
replace movement = 0 if diff == 0

label define movement_label -1 "Up" 0 "Same" 1 "Down"
label values movement movement_label

tab movement
