/*

Where are inspectors after Year 1 transfers? (Y2Q3 and Y2Q2)

Datasets with inspectors and their current circle after transfers took place. 

Author(s):
	Guillermo Palacios
	
Date created:
	April, 2017
	
*/

******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

* Declare input file paths
local hr_q2_2015_file = 			"Data/Raw Data/Current HR Confirmation/150114 HR Verification FY2015 Q2/150216 HR Verification Q2.csv"
local hr_q3_2015_file = 			"Data/Raw Data/Current HR Confirmation/150301 HR Verification FY2015 Q3/150512 HR Verification Q3.csv"

******************************************************************************
* 1. Datasets
******************************************************************************

* 1. HR Confirmation data

foreach i in q2 q3 {

* Data setup
insheet using "`hr_`i'_2015_file'", comma clear
keep if inspector == 1
drop if mi(circle_id)
isid circle_id

* Ensure that hr ID is not missing if circle is not vacant
assert !mi(hr_id1) if ins1 != "" & ins1 != "VACANT"
assert !mi(hr_id2) if ins2 != "" & ins2 != "VACANT"
assert !mi(hr_id3) if ins3 != "" & ins3 != "VACANT"

* Convert start* and end* to string vars
tostring start*, replace
tostring end*, replace
replace start1 = "" if mi(start1) | start1 == "."
replace start2 = "" if mi(start2) | start2 == "."
replace start3 = "" if mi(start3) | start3 == "."
replace end1 = "" if mi(end1) | end1 == "."
replace end2 = "" if mi(end2) | end2 == "."
replace end3 = "" if mi(end3) | end3 == "."

* Circle's history during the quarter
reshape long hr_id ins ins_ac start end, i(circle_id) j(j)

* Remove missing spaces
preserve
drop if  mi(hr_id) // instead of drop if  !mi(end) | mi(hr_id)
keep circle_id hr_id j ins ins_ac start end
tempfile long_hr_`i'_data
save `long_hr_`i'_data'
restore

}

* 2. Transfers tables

clear all
* List of files in directory
local pref_files : dir "Data\Raw Data\FY 14 Transfers/Transfer Tables FULL/" files "140823*.xlsx"
* Create empty file for Y1 preferences
tempfile transfer_table
save `transfer_table', emptyok
* Append all files in directory
foreach file in `pref_files' { 
	import excel using "Data\Raw Data\FY 14 Transfers/Transfer Tables FULL/`file'", firstrow clear
	append using `transfer_table'
	sa `transfer_table', replace
}
rename HRID hr_id
rename NewCircle circle_id_tt
keep hr_id circle_id_tt
drop if circle_id_tt==.
tempfile transfers_tables
save `transfers_tables'

* 3. Admin data

use "Data/Cleaned Data\Administrative Data\Quarterly\FY2015 Q2/FY2015 Q2", clear 
duplicates report hr_id
duplicates report circle_id hr_id
rename division_id division_id_admi
tempfile admi_data_q2
save `admi_data_q2'

use "Data/Cleaned Data\Administrative Data\Quarterly\FY2015 Q3/FY2015 Q3", clear 
duplicates report hr_id
duplicates report circle_id hr_id
rename division_id division_id_admi
tempfile admi_data_q3
save `admi_data_q3'

******************************************************************************
* 2. Final datasets
******************************************************************************

* 1. First inspector that was in each circle

foreach i in q2 q3 {

use `long_hr_`i'_data', clear
keep circle_id hr_id j
bys circle_id: egen min_j=min(j)
keep if j==min_j
merge m:1 hr_id using `transfers_tables'
drop if _m==2
drop _m
gen flag=circle_id!=circle_id_tt & !mi(circle_id_tt)
replace flag=. if mi(circle_id_tt)
bys hr_id: egen min_flag=min(flag)
tab min_flag

preserve
keep if min_flag==1
duplicates drop hr_id, force
count 
restore

keep circle_id hr_id 
isid circle_id
*rename circle_id circle_id_begin_`i'
tempfile ins_begin_`i'
save `ins_begin_`i''
save "TP Analysis/Coded Data/ins_begin_`i'", replace
}

* 2. Circle where inspector was at the end of the quarter 

foreach i in q2 q3  {

use `long_hr_`i'_data', clear
keep circle_id hr_id j
bys circle_id: egen max_j=max(j)
keep if j==max_j
merge m:1 hr_id using `transfers_tables', nogen keep(1 3)
gen flag=circle_id!=circle_id_tt & !mi(circle_id_tt)
replace flag=. if mi(circle_id_tt)
bys hr_id: egen min_flag=min(flag)
tab min_flag

preserve
keep if min_flag==1
duplicates drop hr_id, force
count 
restore

keep circle_id hr_id 
isid circle_id
*rename circle_id circle_id_end_`i'
tempfile ins_end_`i'
save `ins_end_`i''
save "TP Analysis/Coded Data/ins_end_`i'", replace
}
