/*
Adds Y2 Q1 data to Y1 Analysis dataset, and adds Y2 Q1 data to Y2 Analysis dataset.

Authors:
	Ismail Khan (2015-)

Date created:
	Feb 11, 2016

*/

********************************************************************************
* Intial Setup
********************************************************************************

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

* Declare input files
local input_folder = 				"TP Analysis/Coded Data"
local y2_analysis =					"`input_folder'/TP Y2 Analysis Data"
local y1_analysis = 				"`input_folder'/150525 TP Analysis Data"
local y1_analysis_y1_treat = 		"`input_folder'/150525 TP Analysis Data w Y2 Treatment"
local y3q1_data = 					"Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To TP Randomization/2016_q1.dta"

* Declare output files
local output_folder = 				"TP Analysis/Coded Data"
local y2q1_demand_output = 			"`output_folder'/Y2 Q1 Demand"
local y3q1_demand_output = 			"`output_folder'/Y3 Q1 Demand"


********************************************************************************
* Save Y2 Q1 Net and Gross Demand
********************************************************************************

use "`y2_analysis'", clear

keep if qtr == 1
keep circle_id gross_dem* net_dem* ln_gross_dem* ln_net_dem*
ren (*gross_dem* *net_dem*) (*y2q1_gross_dem* *y2q1_net_dem*)

sa "`y2q1_demand_output'", replace


********************************************************************************
* Save Y3 Q1 Net and Gross Demand
********************************************************************************

use "`y3q1_data'", clear

keep circle_id gross_dem* net_dem*

* Compute log of each variable
foreach var in gross_dem net_dem {
	foreach x in t c a {
		gen ln_`var'_`x' = log(`var'_`x')
	}
}

ren (*gross_dem* *net_dem*) (*y3q1_gross_dem* *y3q1_net_dem*)

sa "`y3q1_demand_output'", replace
