version 12

quietly {
**************************************************************************************************
*SET WORKSPACE
**************************************************************************************************

clear all
set mem 400m
set more off
pause on
cap log close
set maxvar 32767

cap cd "$PAKTAX2_RANDOMIZATION"

local num 2000
set obs 1
g temp1=c(current_date)
g temp2=date(temp1,"DMY")
g temp3=year(temp2)
tostring temp3, replace
g year=substr(temp3,3,2)
g month=month(temp2)
g day=day(temp2)
tostring month day, replace
replace month="0"+month if length(month)==1
replace day="0"+day if length(day)==1
global DATE = year+month+day
display $DATE


*PILOT BALLOT
**************************************************************************************************

*1. Open PILOT datasets

use "Output/Year 1/130726 Lahore PILOT Transfers Randomization Output 150.dta", clear
tempfile lahore_pilot
save `lahore_pilot'

use "Output/Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta", clear
tempfile lahore_pilot_merge
save `lahore_pilot_merge'

use "Output/Year 1/130803 Multan PILOT Transfers Randomization Output 51135.dta", clear
tempfile multan_pilot
save `multan_pilot'

use "Output/Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta", clear
tempfile multan_pilot_merge
save `multan_pilot_merge'


**************************************************************************************************
**************************************************************************************************
*LAHORE BALLOT
**************************************************************************************************
**************************************************************************************************

*Main randomization Lahore: circles to groups
**************************************************************************************************

forvalues m=1/`num' {

************************************************************************************************

*1. Create sample
use "Data for Ballot\Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL",clear 
local initial_total_obs `r(N)' 

**************************************************************************************************

*1. Create sample
*Keep only eligible circles in Lahore 
keep if partition_id == 5 // Keep only Lahore A, Lahore B

*****INSERT PILOT SEED HERE!!!*****  
merge 1:1 division_id circle_id using `lahore_pilot_merge'

assert _merge != 2 // hard check that no circles in pilot that are not in main 
count if _merge == 3
assert `r(N)' == 10 // hard check that we only have 10 circles in pilot  
replace main_exclude = 1 if _merge == 3 
drop _merge 
drop if main_exclude == 1 // Exclude ineligible circles (including pilot) 
 
qui count
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  
summ number_circles if partition_id == 5, d
local number_circles = `r(mean)' 

assert stratum_id != .

 
**************************************************************************************************
*2. Allocate circles in main sample to groups // 5000 ITERATIONS

sort stratum_id circle_id 
**Select seed for main ballot 
set seed `m'
set sortseed `m'

sort stratum_id circle_id 
g rand2 = runiform()	
by stratum_id: egen rank2 = rank(rand2), unique // rank2 within strata 
by stratum_id: egen count2 = count(rand2)

**Allocate circles into groups by stratified randomization. 
**First figure out the number of groups we need. 
**Ideal group size is 10 circles.  We get as close as possible to this.  

*Preparing for allocation
local num_groups = floor(`number_circles'/10) 
local test1 = abs(`number_circles'/`num_groups' - 10)
local test2 = abs(`number_circles'/(`num_groups' + 1) - 10) 

if `test1' > `test2' { // if adding a group brings average closer to 10, then add a group  
	local num_groups = `num_groups' + 1 
}	

g group = .  
levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	count if division_id == `d'
	local num_circles = `r(N)'
	local per_group = floor(`num_circles'/`num_groups')
	local per_bin = floor(`per_group'/3) 

	forvalues i = 1(1)`num_groups'{
		#delimit ; 
		replace group = `i' if rank2 >= `per_bin' *(`i'-1) + 1 
			& rank2 <= `per_bin' *`i' & division_id == `d' ; 
		#delimit cr 
	}
}

**Now deal with the residual circles. 
**Randomly rank strata
sort stratum_id circle_id
by stratum_id: g temprand1 = runiform() if _n == 1 
egen strata_rank = rank(temprand1), unique  
by stratum_id: egen temp = max(strata_rank) 
replace strata_rank = temp 
drop temp 

**Randomly rank group
sort group circle_id
by group: g temprand2 = runiform() if _n == 1 & group != .
egen group_rank = rank(temprand2), unique  
by group: egen temp = max(group_rank) 
replace group_rank = temp 
drop temp 

summ strata_rank if partition_id == 5, d
local strata_max = `r(max)' 
local grouprank_counter = 1 

forvalues s = 1(1)`strata_max'{
	count if group == . & strata_rank == `s' // number of remaining circles in randomly selected strata
	local remaining_circles = `r(N)' 
	
	while `remaining_circles' > 0 {
		summ rank2 if strata_rank == `s' & group == . , d
		local min_rank = `r(min)' 
		summ group if group_rank == `grouprank_counter', d
		local group = `r(min)'  
		replace group = `group' if rank2 == `min_rank' & strata_rank == `s' 

		local grouprank_counter = `grouprank_counter' + 1 
		if `grouprank_counter' > `num_groups' {
			local grouprank_counter 1		
		}	
		
		count if group == . & strata_rank == `s' // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	}
	count if group == . & strata_rank == `s'
	assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
}
count if group == . 
assert `r(N)' == 0 // make sure no circles are without a group allocation
replace group = group + 1 // adjust for pilot group that came in Lahore before 

**************************************************************************************************
*3. Save data, outsheet groups, and display groups of circles
tempfile rand_`m'
save `rand_`m'', replace


*Second randomization Lahore: treatment assignment
**************************************************************************************************

*1. Open sample from first ballot - Pilot Seed == 150, Main Seed == 1170000
use `rand_`m'', clear
assert group != . // assert that no circle has been left unallocated 

************************************************************************************************

*2. Select 4 groups from Lahore for treatment

sort group circle_id 
by group: g rand3 = runiform() if _n == 1 
egen rank3 = rank(rand3), unique // rank3 within group 
by group: egen temp = max(rank3) 
replace rank3 = temp 
drop temp

**Select groups for treatment.  
g treatment = ""
replace treatment = "CHOICE GROUP 1" if rank3 == 1 
replace treatment = "CHOICE GROUP 2" if rank3 == 2
replace treatment = "CHOICE GROUP 3" if rank3 == 3
replace treatment = "CHOICE GROUP 4" if rank3 == 4
g lottery_group = treatment 

**Select which groups will be ranked by recovery and which groups by demand
sort treatment circle_id
by treatment: g rand4 = runiform() if _n == 1 & treatment != "" 
egen rank4 = rank(rand4), unique // rank4 within treatment group
by treatment: egen temp = max(rank4)
replace rank4 = temp
drop temp

g ranking_method = ""
replace ranking_method = "RECOVERY" if rank4 == 1
replace ranking_method = "RECOVERY" if rank4 == 2
replace ranking_method = "DEMAND" if rank4 == 3
replace ranking_method = "DEMAND" if rank4 == 4

************************************************************************************************

*3. Balance Checks
cap drop ln*
for any gross_dem_c gross_dem_t net_dem_c net_dem_t recov_tot_c recov_tot_t recov_tot_t_12q3: g ln_X = ln(X) 
g ln_change_recovery = ln(recov_tot_t/recov_tot_t_12q3) 

desc ln*, varlist
local sumstatvars "`r(varlist)'"
local number_variables `r(N)' 

forvalues i = 1(1)18{
	g col`i' = . // column placeholders
}

*Calculate summary statistics
local variable_number = 1
foreach var in `sumstatvars'{
	summ `var' if treatment == "CHOICE GROUP 1", d
	replace col1 = `r(mean)' if _n == `variable_number'
	replace col2 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 1"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col3 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col4 = `r(p)' if _n == `variable_number' 
	drop temp
	
	summ `var' if treatment == "CHOICE GROUP 2", d 
	replace col5 = `r(mean)' if _n == `variable_number'
	replace col6 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 2"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col7 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col8 = `r(p)' if _n == `variable_number' 
	drop temp

	summ `var' if treatment == "CHOICE GROUP 3", d 
	replace col9 = `r(mean)' if _n == `variable_number'
	replace col10 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 3"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col11 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col12 = `r(p)' if _n == `variable_number' 
	drop temp

	summ `var' if treatment == "CHOICE GROUP 4", d 
	replace col13 = `r(mean)' if _n == `variable_number'
	replace col14 = `r(N)' if _n == `variable_number' 
	
	*T-Tests
	g temp = 1 if treatment == "CHOICE GROUP 4"
	replace temp = 0 if treatment == ""
	ttest `var', by(temp) 
	replace col15 = `r(mu_2)' - `r(mu_1)' if _n == `variable_number'  
	replace col16 = `r(p)' if _n == `variable_number' 
	drop temp

	summ `var' if treatment == "", d 
	replace col17 = `r(mean)' if _n == `variable_number'
	replace col18 = `r(N)' if _n == `variable_number' 

	forvalues i = 1(1)18{
		replace col`i' = round(col`i', 0.001) if _n == `variable_number' 
	}
	local variable_number = `variable_number' + 2
}

************************************************************************************************

*4. Save data & and display treatment groups
sort group division_name circle_id
tempfile Lahore_`m'
save `Lahore_`m'', replace


**************************************************************************************************
*OTHER DIVISION BALLOT
**************************************************************************************************

/*
Main randomization Other Div: circles to groups
*/

use "Data for Ballot\Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL - Non-Lahore",clear 
local initial_total_obs `r(N)' 

**************************************************************************************************

*1. Create sample
*Keep only eligible circles in other divisions
drop if partition_id == 5 // Drop Lahore A, Lahore B as this has already been balloted
drop if inlist(partition_id, 2, 6, 9) // Drop DG Khan, Lahore C, and Sahiwal 

*****INSERT PILOT SEED HERE!!!*****  
merge 1:1 division_id circle_id using `multan_pilot_merge'

assert _merge != 2 // hard check that no circles in pilot that are not in main 
count if _merge == 3
assert `r(N)' == 10 // hard check that we only have 10 circles in pilot  
replace main_exclude = 1 if _merge == 3 
drop _merge

drop if main_exclude == 1 // Exclude ineligible circles (including pilot) 
 
qui count
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  

assert stratum_id != .  

tempfile data_no_lahore
save `data_no_lahore'

**************************************************************************************************

*2. Allocate circles in main sample to groups 

use `data_no_lahore', clear

sort stratum_id circle_id 
**Select seed for main ballot 
set seed `m'
set sortseed `m'

sort stratum_id circle_id 
g rand6 = runiform()	
by stratum_id: egen rank6 = rank(rand6), unique // rank6 within strata 
by stratum_id: egen count6 = count(rand6)

**Allocate circles into groups by stratified randomization. 
**First figure out the number of groups we need. 
**Ideal group size is 10 circles.  We get as close as possible to this.  

*Preparing for allocation 
g num_groups = floor(number_circles/10) 
g test1 = abs(number_circles/num_groups - 10)
g test2 = abs(number_circles/(num_groups + 1) - 10) 

levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ test1 if partition_id == `i', d
	local test1 `r(mean)'
	summ test2 if partition_id == `i', d
	local test2 `r(mean)'
	
	if (`test1' > `test2') { // if adding a group brings average closer to 10, then add a group  
		replace num_groups = num_groups + 1 if partition_id == `i'
	}
}

g group = .  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	count if partition_id == `i'
	local num_circles = `r(N)'
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	local per_group = floor(`num_circles'/`num_groups')
	local per_bin = floor(`per_group'/3) 

	forvalues g = 1(1)`num_groups'{
		#delimit ; 
		replace group = `g' if rank6 >= `per_bin' *(`g'-1) + 1 
			& rank6 <= `per_bin' *`g' & partition_id == `i' ; 
		#delimit cr 
	}
}

**Now deal with the residual circles.  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	**Randomly rank strata
	sort stratum_id circle_id
	by stratum_id: g temprand1 = runiform() if _n == 1 & partition_id == `i'
	egen strata_rank = rank(temprand1), unique 
	by stratum_id: egen temp = max(strata_rank) 
	replace strata_rank = temp 
	drop temp 

	**Randomly rank group
	sort partition_id group circle_id
	by partition_id group: g temprand2 = runiform() if _n == 1 & group != . & partition_id == `i'
	egen group_rank = rank(temprand2), unique   
	by partition_id group: egen temp = max(group_rank) 
	replace group_rank = temp 
	drop temp 
	
	summ strata_rank if partition_id == `i', d
	local strata_max = `r(max)' 
	local grouprank_counter = 1 

	forvalues s = 1(1)`strata_max'{
		count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	
		while `remaining_circles' > 0 {
			summ rank6 if strata_rank == `s' & group == . & partition_id == `i', d
			local min_rank = `r(min)' 
			summ group if group_rank == `grouprank_counter' & partition_id == `i', d
			local group = `r(min)'  
			replace group = `group' if rank6 == `min_rank' & strata_rank == `s' & partition_id == `i'

			local grouprank_counter = `grouprank_counter' + 1 
			if `grouprank_counter' > `num_groups' {
				local grouprank_counter = 1 		
			}	
		
			count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
			local remaining_circles = `r(N)' 
		}
		count if group == . & strata_rank == `s' & partition_id == `i' 
		assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
	}

	drop temprand* strata_rank group_rank
}

count if group == . 
assert `r(N)' == 0 // make sure no circles are without a group allocation
replace group = group + 1 if partition_id == 7 // adjust for pilot group that came in Multan before 

**************************************************************************************************

*3. Save data, outsheet groups, and display groups of circles

tempfile otherdiv_`m'
save `otherdiv_`m''

/*
Second randomization Otherdiv: treatment assignment
*/

use `otherdiv_`m'', clear

sort partition_id group circle_id
by partition_id group: g rand7 = runiform() if _n == 1 
by partition_id: egen rank7 = rank(rand7), unique // rank7 groups within a partition  
by partition_id group: egen temp = max(rank7)
replace rank7 = temp 
drop temp

**Select groups for treatment.  
g treatment = ""
replace treatment = "CHOICE GROUP 1" if rank7 == 1 
replace treatment = "CHOICE GROUP 2" if rank7 == 2
replace treatment = "" if rank7 == 2 & partition_id == 10 // Sarghoda should only have 1 treatment group 
g lottery_group = treatment 

**Select which groups will be ranked by recovery and which groups by demand
sort partition_id treatment circle_id
by partition_id treatment: g rand8 = runiform() if _n == 1 & treatment != "" 
by partition_id: egen rank8 = rank(rand8), unique // rank8 treatment groups within a partition 
by partition_id treatment: egen temp = max(rank8)
replace rank8 = temp
drop temp

g ranking_method = ""
replace ranking_method = "RECOVERY" if rank8 == 1 // This will ensure Sarghoda gets ranked by recovery 
replace ranking_method = "DEMAND" if rank8 == 2

************************************************************************************************

*3. Save data & and display treatment groups

sort division_name group circle_id
tempfile Otherdiv_`m'
save `Otherdiv_`m'', replace

version 13 // BY INCLUDING THE RIGHT SEEDS, CHECK THIS IS CORRECT (THAT STATA USES V13 FROM NOW ONWARDS)
			// THE SECOND APPROACH (CREATING RAND NUM BEFORE/AFTER DOES NOT WORK - EQUAL)
			
**************************************************************************************************
*Y2 BALLOT
**************************************************************************************************

/*
Prepare Y2 datasets // Y1 Treatment
*/

*1. CREATE TEMPFILE FOR UPDATED HR NAMES
//I don't think I need to do this // I have deleted many lines of code that edit hr names.

********************************************************************************

*2. CREATE DATASET FOR BALLOT OF YEAR 1 TREATED GROUPS 

use `Lahore_`m'', clear
append using `Otherdiv_`m''
count
assert `r(N)' == 410

/*keep relevant variables*/
keep division* district* partition* stratum* circle* hr* treatment* lottery_group* group ranking_method

/*keep only circles treated in year 1*/
keep if !missing(treatment)
count
*assert `r(N)' == 153 // Not necessarily, depends on the groups....
 
/*save file*/ 
tempfile treated_groups_ballot_`m'
save `treated_groups_ballot_`m'', replace

/*
Y2 Ballot for Y1 Treatment Groups
*/

use `treated_groups_ballot_`m'', clear

count
*assert `r(N)' == 153 // 153 circles
assert !missing(treatment) // all treated
assert !missing(ranking_method) // ranking method 
isid circle_id // circle-level data

/*generate group number variable so each group has a unique number across partitions*/ 
sort partition_id group 
egen assigned_group = group(partition_id group)

/*create updated treatment variable*/ 
drop treatment
g treatment = . 
label var treatment "treatment status for year 2 ballot" 

/*create treatment details variable*/
g details_treatment = "dynamic incentives in year 1" 
label var details_treatment "details about treatment status" 

/*create numeric ranking variable*/ // demand == 1, recovery == 2 
g ranking_method_num = 1 if ranking_method == "DEMAND"
replace ranking_method_num = 2 if ranking_method == "RECOVERY" 
label define rank 1 "DEMAND" 2 "RECOVERY"
label values ranking_method_num rank 

/*sort*/ 
sort partition_id ranking_method assigned_group circle_id

********************************************************************************
*2. Allocate groups into Year 2 treatment/control 

**Select seed for ballot 

set seed `m'
set sortseed `m'

*************Lahore (partition_id == 5) **********************

/*loop through demand/recovery groups and randomly select 1 each for treatment*/
forvalues i = 1/2{
	local ranking_method : word `i' of "DEMAND" "RECOVERY"

	**randomly order demand/recovery groups 
	#delimit ; 
	sort partition_id ranking_method assigned_group circle_id ; 
	
	by partition_id ranking_method assigned_group: g rand_lahore`i' = runiform() if _n == 1 
		& inlist(partition_id, 5) & ranking_method == "`ranking_method'" ; 

	egen rank_lahore`i' = rank(rand_lahore`i'), unique ; // rank recovery groups in  lahore
	
	by partition_id ranking_method assigned_group: egen temp = max(rank_lahore`i') ; 
	replace rank_lahore`i' = temp ; 
	drop temp ;
	#delimit cr 

	**assign first demand/recovery group to treatment
	replace treatment = 1 if rank_lahore`i' == 1 
} 

/*confirm we have selected 1 demand & 1 recovery*/ 
summ ranking_method_num if treatment == 1, d
assert `r(min)' == 1 // 1 demand group selected
assert `r(max)' == 2 // 1 recovery group selected

************** Remaining Divisions *******************************

/*randomly order all divisions except Lahore and Sarghoda*/ 
sort partition_id ranking_method assigned_group circle_id
by partition_id: g rand_div = runiform() if _n == 1 & !inlist(partition_id, 5, 10)
egen rank_div = rank(rand_div), unique // rank remaining divisions
by partition_id: egen temp = max(rank_div)
replace rank_div = temp
drop temp

/*randomly pick first group in first division*/ 
sort partition_id ranking_method assigned_group circle_id
by partition_id ranking_method: g rand_group = runiform() if _n == 1 & rank_div == 1 
egen rank_group = rank(rand_group), unique // rank recovery/demand groups within first division
by partition_id ranking_method: egen temp = max(rank_group)
replace rank_group = temp
drop temp

/*assign first group in first division to treatment*/
replace treatment = 1 if rank_div == 1 & rank_group == 1 

/*determine whether this group is demand or recovery*/  
summ ranking_method_num if rank_div == 1 & rank_group == 1
local group_type = `r(mean)' // 1 == demand, 2 == recovery 

/*now, go through the next three divisions,
alternating between recovery, demand selection:*/
replace treatment = 1 if inlist(rank_div, 2, 4) & ranking_method_num != `group_type'
replace treatment = 1 if inlist(rank_div, 3) & ranking_method_num == `group_type'

************** Sarghoda (partition_id == 10)  & Last Division*********************

/*determine whether Sarghoda will be in treatment*/  
sort partition_id ranking_method assigned_group circle_id
g rand_sgd = runiform() if _n <= 2 // generate two random numbers 
egen rank_sgd = rank(rand_sgd), unique // rank these numbers

/*if number in _n == 1 is ranked first, then Sarghoda's recovery group is selected
and last division's demand group is selected*/  
summ rank_sgd if _n == 1
local rank_sgd `r(mean)' 

if `rank_sgd' == 1{
	replace treatment = 1 if partition_id == 10 & ranking_method_num == 2 // Sarghoda recovery group
	replace treatment = 1 if rank_div == 5 & ranking_method_num == 1 // Last division demand group
}

/*otherwise go to the last division and select its recovery group*/
if `rank_sgd' == 2{
	replace treatment = 1 if rank_div == 5 & ranking_method_num == 2 // Last division recovery group
}

/*finally, assign remaining groups to control*/ 
replace treatment = 0 if missing(treatment) 

/*update treatment details variable*/
replace details_treatment = "dynamic incentives in year 1 & year 2" if treatment == 1 

********************************************************************************
*3. Save files and display 

/*save files*/ 
tempfile treated_groups_y2_rand_`m'
save `treated_groups_y2_rand_`m''
}


/*
Prepare Y2 datasets // Y1 Control
*/

*1. CREATE DATASET FOR BALLOT OF NEW DIVISIONS (LAHORE C, DG KHAN, SAHIWAL)  // this one is the same for everyone (and same as before), so no change here
// At some point you will call: New Groups Ballot.dta

*2. CREATE DATASET FOR BALLOT OF PREVIOUS EXCLUDED CIRCLES  

/*Get strata information for each partition*/ 
use "Data for Ballot/Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FINAL - Non-Lahore.dta", clear

/*Regenerate a strata variable and store cutoffs in variables*/ 
local numbins 3 // number of bins within each partition 
for any recov_tot_t: g ln_X = ln(X)  // create log total recovery 
local stratify_variable ln_recov_tot_t 

levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	xtile new_bins`d' = `stratify_variable' if division_id == `d', nq(`numbins') // stratify on total recovery 
	pctile temp`d' = `stratify_variable' if division_id == `d', nq(`numbins') 
	g bottom`d' = `r(r1)' // store bottom cutoff in variable
	g top`d' = `r(r2)' // store top cutoff in variable 
}
summ division_id, d
g new_stratum_id = new_bins`r(min)' // create one variable for all bins 
levelsof division_id if division_id != 1, local(divisions)
foreach d of numlist `divisions'{
	local j = `d' - 1
	local temp = `j'*`numbins'
	replace new_stratum_id = new_bins`d' + `temp' if division_id == `d'
}
assert new_stratum_id == stratum_id // confirm regeneration is correct 

/*Save tempfile*/
keep division_id top* bottom* 
duplicates drop
tempfile strata
save "`strata'", replace

/*Get excluded circles*/ 
use "Data for Ballot/Punjab Compiled - Quarterly - For FY2014 Transfers & Postings Ballot - FULL SET - Non-Lahore.dta", clear
keep if main_exclude == 1

/*Number of excluded*/ 
qui count
local num_excluded `r(N)' 

/*Keep relevant variables*/ 
keep division* partition* circle* hr* recov_tot_t 

/*Compare to current data*/
merge 1:1 circle_id using "Data for Ballot/2014_q3_crosswalk_OLD.dta", ///
	keepusing(q3_2013_recov_tot_c q3_2013_recov_tot_a) assert(using match) keep(match) nogen

/*Create total recovery variable*/ 
egen q3_2013_recov_tot_t = rowtotal(q3_2013_recov_tot_c q3_2013_recov_tot_a), missing 

g test = abs(q3_2013_recov_tot_t - recov_tot_t)
summ test, d // very close match (2 obs off by value of 1) so we are okay
drop recov_tot_t test

/*Do not re-include circles with missing recovery*/
drop if q3_2013_recov_tot_t == . // 2 circles 

/*Now assign strata using variable values*/
merge n:1 division_id using "`strata'", keep(match) nogen

for any q3_2013_recov_tot_t: g ln_X = ln(X)  // create log total recovery 
local stratify_variable ln_q3_2013_recov_tot_t
levelsof division_id, local(divisions)
foreach d of numlist `divisions'{
	g bins`d' = . 
	replace bins`d' = 1 if `stratify_variable' <= bottom`d' & `stratify_variable' != . & division_id == `d' 
	replace bins`d' = 2 if `stratify_variable' > bottom`d' & `stratify_variable' <= top`d' & `stratify_variable' != .  & division_id == `d' 
	replace bins`d' = 3 if `stratify_variable' > top`d'  & `stratify_variable' != . & division_id == `d' 
}

summ division_id, d
g stratum_id = bins`r(min)' // create one variable for all bins 
levelsof division_id if division_id != 1, local(divisions)
foreach d of numlist `divisions'{
	local j = `d' - 1
	local temp = `j'*`numbins'
	replace stratum_id = bins`d' + `temp' if division_id == `d'
}
drop bins* top* bottom* 
assert !missing(stratum_id) 

/*Dummy variable for excluded circles*/
g excluded = 1 
label var excluded "excluded in Year 1 ballot" 

tempfile excluded_circles
save "`excluded_circles'", replace

forvalues m=1/`num' {

preserve
/*Append to previously created control groups*/ 
use `Lahore_`m'', clear
append using `Otherdiv_`m''
gen old=1
keep if missing(treatment) 

append using "`excluded_circles'"

count if missing(group)
assert `r(N)' == `num_excluded' - 2 // 2 excluded from the list of excluded circles

/*Save file*/ 
order partition_id division_id division_name circle_id hr_id  stratum_id 
drop *rand* *rank* count* num* test* treatment 
tempfile excluded_circles_ballot_`m'
save `excluded_circles_ballot_`m''
restore
}

**************************************************************************************************
***PREVIOUSLY EXCLUDED DIVISIONS
**************************************************************************************************

*1. Create sample for previously excluded divisions
use "Output/Year 1/140804 New Groups Ballot.dta", clear
assert inlist(partition_id, 2, 6, 9) // Confirm only DG Khan, Lahore C and Sahiwal 

qui count 
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  
assert stratum_id != .  

tempfile new_groups
save `new_groups'

**************************************************************************************************

*2. Allocate circles to groups for previously excluded divisions
sort stratum_id circle_id 

forvalues m=1/`num' {

use `new_groups', clear
**Select seed for main ballot 
set seed `m'
set sortseed `m'

sort stratum_id circle_id 
g rand1 = runiform()	
by stratum_id: egen rank1 = rank(rand1), unique // rank1 within strata 
by stratum_id: egen count1 = count(rand1)

**Allocate circles into groups by stratified randomization. 
**First figure out the number of groups we need. 
**Ideal group size is 10 circles.  We get as close as possible to this.  

*Preparing for allocation 
g num_groups = floor(number_circles/10) 
g test1 = abs(number_circles/num_groups - 10)
g test2 = abs(number_circles/(num_groups + 1) - 10) 

levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ test1 if partition_id == `i', d
	local test1 `r(mean)'
	summ test2 if partition_id == `i', d
	local test2 `r(mean)'
	
	if (`test1' > `test2') { // if adding a group brings average closer to 10, then add a group  
		replace num_groups = num_groups + 1 if partition_id == `i'
	}
}

g group = .  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	count if partition_id == `i'
	local num_circles = `r(N)'
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	local per_group = floor(`num_circles'/`num_groups')
	local per_bin = floor(`per_group'/3) 

	forvalues g = 1(1)`num_groups'{
		#delimit ; 
		replace group = `g' if rank1 >= `per_bin' *(`g'-1) + 1 
			& rank1 <= `per_bin' *`g' & partition_id == `i' ; 
		#delimit cr 
	}
}

**Now deal with the residual circles.  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	**Randomly rank strata
	sort stratum_id circle_id
	by stratum_id: g temprand1 = runiform() if _n == 1 & partition_id == `i'
	egen strata_rank = rank(temprand1), unique 
	by stratum_id: egen temp = max(strata_rank) 
	replace strata_rank = temp 
	drop temp 

	**Randomly rank group
	sort partition_id group circle_id
	by partition_id group: g temprand2 = runiform() if _n == 1 & group != . & partition_id == `i'
	egen group_rank = rank(temprand2), unique   
	by partition_id group: egen temp = max(group_rank) 
	replace group_rank = temp 
	drop temp 
	
	summ strata_rank if partition_id == `i', d
	local strata_max = `r(max)' 
	local grouprank_counter = 1 

	forvalues s = 1(1)`strata_max'{
		count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	
		while `remaining_circles' > 0 {
			summ rank1 if strata_rank == `s' & group == . & partition_id == `i', d
			local min_rank = `r(min)' 
			summ group if group_rank == `grouprank_counter' & partition_id == `i', d
			local group = `r(min)'  
			replace group = `group' if rank1 == `min_rank' & strata_rank == `s' & partition_id == `i'

			local grouprank_counter = `grouprank_counter' + 1 
			if `grouprank_counter' > `num_groups' {
				local grouprank_counter = 1 		
			}	
		
			count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
			local remaining_circles = `r(N)' 
		}
		count if group == . & strata_rank == `s' & partition_id == `i' 
		assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
	}

	drop temprand* strata_rank group_rank
}

count if group == . 
assert `r(N)' == 0 // make sure no circles are without a group allocation
tempfile new_groups_main_rand_`m'
save `new_groups_main_rand_`m'', replace

*************************************************************************************************
***PREVIOUSLY EXCLUDED CIRCLES
**************************************************************************************************

*3. Create sample for previously excluded circles
use `excluded_circles_ballot_`m'', clear
qui count
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  
assert stratum_id != .  

set seed `m'
set sortseed `m'

*4. Allocate previously excluded circles to groups (SARGHODA) 
/*Set seed again*/ 
sort stratum_id circle_id 

**Allocate circles into groups: 

**First, start with Sarghoda (partition_id == 10):
**Since there is only 1 control group, we have to create 2 new groups: 
sort stratum_id circle_id 
g rand1 = runiform()	
by stratum_id: egen rank1 = rank(rand1), unique // rank1 within strata 
by stratum_id: egen count1 = count(rand1)

*Preparing for allocation 
replace group = . if partition_id == 10 // remove previous group assignment
g num_groups = 2 if partition_id == 10 
local num_groups 2 

count if partition_id == 10
local num_circles = `r(N)'
	
local per_group = floor(`num_circles'/`num_groups')
local per_bin = floor(`per_group'/3) 

forvalues g = 1(1)`num_groups'{
	#delimit ; 
	replace group = `g' if rank1 >= `per_bin' * (`g'-1) + 1 
		& rank1 <= `per_bin' *`g' & partition_id == 10; 
	#delimit cr 
}

**Now deal with the residual circles.  
summ num_groups if partition_id == 10, d
local num_groups `r(mean)' 
	
**Randomly rank strata
sort stratum_id circle_id
by stratum_id: g temprand1 = runiform() if _n == 1 & partition_id == 10
egen strata_rank = rank(temprand1), unique 
by stratum_id: egen temp = max(strata_rank) 
replace strata_rank = temp 
drop temp 

**Randomly rank group
sort partition_id group circle_id
by partition_id group: g temprand2 = runiform() if _n == 1 & group != . & partition_id == 10
egen group_rank = rank(temprand2), unique   
by partition_id group: egen temp = max(group_rank) 
replace group_rank = temp 
drop temp 
	
summ strata_rank if partition_id == 10, d
local strata_max = `r(max)' 
local grouprank_counter = 1 

forvalues s = 1(1)`strata_max'{
	count if group == . & strata_rank == `s' & partition_id == 10 // number of remaining circles in randomly selected strata
	local remaining_circles = `r(N)' 
	
	while `remaining_circles' > 0 {
		summ rank1 if strata_rank == `s' & group == . & partition_id == 10, d
		local min_rank = `r(min)' 
		summ group if group_rank == `grouprank_counter' & partition_id == 10, d
		local group = `r(min)'  
		replace group = `group' if rank1 == `min_rank' & strata_rank == `s' & partition_id == 10

		local grouprank_counter = `grouprank_counter' + 1 
		if `grouprank_counter' > `num_groups' {
			local grouprank_counter = 1 		
		}	
		
		count if group == . & strata_rank == `s' & partition_id == 10 // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	}
	count if group == . & strata_rank == `s' & partition_id == 10 
	assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
}
drop rank1* rand1* temprand* strata_rank group_rank

count if group == . & partition_id == 10 
assert `r(N)' == 0 // make sure no circles are without a group allocation

**************************************************************************************************
*5. Allocate previously excluded circles to groups (REMAINING DIVISIONS) 
sort partition_id group circle_id 
levelsof partition_id if missing(group), local(partitions) // partitions with excluded circles
foreach i of numlist `partitions'{
	
	levelsof stratum_id if missing(group) & partition_id == `i', local(strata) // strata with excluded circles 
	foreach s of numlist `strata'{
		sort partition_id group	circle_id 
		by partition_id group: egen num_circles_strata = total(stratum_id == `s') ///
			if group != .  & partition_id == `i' // determine number of circles in that strata in each group
		
		**Randomly rank group
		g group_rank = . 
		local corrector = 0 // corrector for generating one group rank 
		levelsof num_circles_strata, local(num_circles) 
		foreach n of numlist `num_circles'{
			sort partition_id group circle_id 
			by partition_id group: g rand2_`n' = runiform() /// 
				if _n == 1 & group != . & num_circles_strata == `n' & partition_id == `i'
			egen temp1 = rank(rand2_`n'), unique   
			by partition_id group: egen temp2 = max(temp1) 
			replace group_rank = temp2 + `corrector' if missing(group_rank) 
			drop temp1 temp2  
		
			summ group_rank
			local corrector `r(max)' 
		}
		local grouprank_counter = 1 
		
		**Randomly rank excluded circles
		sort partition_id group circle_id
		g rand3 = runiform() if missing(group) & stratum_id == `s' & partition_id == `i'
		egen circle_rank = rank(rand3), unique   
		local circlerank_counter = 1 
	
		**Assign circles to groups
		count if group == . & stratum_id == `s' & partition_id == `i' // number of excluded circles in that strata & partition 
		local remaining_circles = `r(N)' 
			
		while `remaining_circles' > 0 {
			**Assign circles to groups 
			summ group if group_rank == `grouprank_counter' & partition_id == `i', d
			local group = `r(min)'  
			
			replace group = `group' if circle_rank == `circlerank_counter' & missing(group) 
			local grouprank_counter = `grouprank_counter' + 1 
			local circlerank_counter = `circlerank_counter' + 1 

			count if group == . & stratum_id == `s' & partition_id == `i' // number of excluded circles in that strata
			local remaining_circles = `r(N)' 
		}
		
		drop group_rank* circle_rank* rand* num_circles_strata
	}
}

assert !missing(group) // confirm no circle without a group 
tempfile excluded_circles_main_rand_`m'
save `excluded_circles_main_rand_`m'', replace

*6. Save data, outsheet groups, and display groups of circles

use `new_groups_main_rand_`m'', clear
append using `excluded_circles_main_rand_`m''

sort group division_name circle_id
tempfile control_groups_main_rand_`m'
save `control_groups_main_rand_`m'', replace

***********************************************************************
*2. Allocate groups into Year 2 treatment/control 

*1. Create sample
use `control_groups_main_rand_`m'', clear
count
*assert `r(N)' == 354 // 354 control circles
isid circle_id // circle-level data
assert !missing(stratum_id) // all strata have been assigned

/*generate group number variable so each group has a unique number across partitions*/ 
sort partition_id group 
egen assigned_group = group(partition_id group)

/*create updated treatment variable*/ 
g treatment = . 
label var treatment "treatment status for year 2 ballot" 

/*create treatment details variable*/
g details_treatment = "control in year 1" 
replace details_treatment = "excluded in year 1" if excluded == 1 | inlist(partition_id, 2, 6, 9)
label var details_treatment "details about treatment status" 

/*create ranking method variables*/ 
g ranking_method = "" 
g ranking_method_num = . // demand == 1, recovery == 2 
label define rank 1 "DEMAND" 2 "RECOVERY"
label values ranking_method_num rank 

/*drop previous randomization variables*/
cap drop rand1 rank1

/*sort*/ 
sort partition_id assigned_group circle_id

********************************************************************************
*2. Allocate groups into Year 2 treatment/control 

**Select seed for ballot 
set seed `m'
set sortseed `m'

*************Lahore A & B (partition_id == 5) **********************

/*randomly select 2 groups for treatment*/

**randomly order groups in Lahore A & B 
sort partition_id assigned_group circle_id 
by partition_id assigned_group: g rand_lahore = runiform() if _n == 1 & inlist(partition_id, 5)  
egen rank_lahore = rank(rand_lahore), unique // rank groups in lahore
by partition_id assigned_group: egen temp = max(rank_lahore)  
replace rank_lahore = temp 
drop temp 

**assign first two groups to treatment
replace treatment = 1 if inlist(rank_lahore, 1, 2)

**assign ranking methods to treatment groups
replace ranking_method = "RECOVERY" if rank_lahore == 1
replace ranking_method = "DEMAND" if rank_lahore == 2 

*************Lahore C, DG Khan, Sahiwal (partition_id == 2, 6, 9) **********************

/*rank Lahore C & DG Khan and assign DG Khan's rank to Sahiwal*/
sort partition_id assigned_group circle_id
by partition_id: g rand_excluded_div = runiform() if _n == 1 & inlist(partition_id, 2, 6) 
egen rank_excluded_div = rank(rand_excluded_div), unique // rank DG Khan and Lahore C
by partition_id: egen temp = max(rank_excluded_div) 
replace rank_excluded_div = temp
drop temp

sum rank_excluded_div if partition_id == 2 // DG Khan's rank
replace rank_excluded_div = `r(mean)' if partition_id == 9 // assign to Sahiwal

/*randomly order groups in the previously excluded divisions*/ 
sort partition_id assigned_group circle_id
by partition_id assigned_group: g rand_lahoreC = runiform() if _n == 1 & partition_id == 6
egen rank_lahoreC = rank(rand_lahoreC), unique // rank groups within Lahore C
by partition_id assigned_group: egen temp = max(rank_lahoreC)
replace rank_lahoreC = temp
drop temp

sort partition_id assigned_group circle_id
by partition_id assigned_group: g rand_DG_Sahiwal = runiform() if _n == 1 & inlist(partition_id, 2, 9) 
egen rank_DG_Sahiwal = rank(rand_DG_Sahiwal), unique // rank groups within Lahore C
by partition_id assigned_group: egen temp = max(rank_DG_Sahiwal)
replace rank_DG_Sahiwal = temp
drop temp

/*assign treatment*/
replace treatment = 1 if rank_lahoreC == 1 
replace treatment = 1 if rank_DG_Sahiwal == 1 

/*assign ranking method*/
replace ranking_method = "RECOVERY" if treatment == 1 & rank_excluded_div == 1
replace ranking_method = "DEMAND" if treatment == 1 & rank_excluded_div == 2

************** Remaining Divisions excluding Sarghoda *******************************

/*randomly select 3 divisions out of the remaining 5 divisions*/ 

**recall that in Year2 Treatment Ballot, we assigned:
**Bahwalpur (part_id == 1), Multan (7), Pindi (8) == Demand 
**Faisalabad (3), Gujranwala (4) == Recovery 
**now we select 3 divisions from demand group for recovery and 1 division from recovery group for demand.

/*randomly order previous demand groups*/
sort partition_id assigned_group circle_id
by partition_id: g rand_div_demand = runiform() if _n == 1 & inlist(partition_id, 1, 7, 8)
egen rank_demand = rank(rand_div_demand), unique // rank prevous demand divisions
by partition_id: egen temp = max(rank_demand)
replace rank_demand = temp
drop temp

/*randomly order groups in first 2 randomly selected divisions*/ 
levelsof partition_id if rank_demand <= 2, local(selected_demand_divisions) 
foreach i of numlist `selected_demand_divisions'{
	sort partition_id assigned_group circle_id
	by partition_id assigned_group: g rand_group`i' = runiform() if _n == 1 & partition_id == `i'
	egen rank_group`i' = rank(rand_group`i'), unique // rank groups within divisions
	by partition_id assigned_group: egen temp = max(rank_group`i')
	replace rank_group`i' = temp
	drop temp
}

/*assign first group in first 2 randomly selected divisions to treatment*/ 
foreach i of numlist `selected_demand_divisions'{
	/*assign to treatment*/
	replace treatment = 1 if rank_group`i' == 1
	
	/*assign to recovery*/
	replace ranking_method = "RECOVERY" if rank_group`i' == 1
}	


/*randomly order previous recovery groups*/
sort partition_id assigned_group circle_id
by partition_id: g rand_div_recov = runiform() if _n == 1 & inlist(partition_id, 3, 4)
egen rank_recovery = rank(rand_div_recov), unique // rank previous recovery divisions
by partition_id: egen temp = max(rank_recovery)
replace rank_recovery = temp
drop temp

/*randomly order groups in first randomly selected division*/ 
levelsof partition_id if rank_recovery == 1, local(selected_recovery_divisions) 
foreach i of numlist `selected_recovery_divisions'{
	sort partition_id assigned_group circle_id
	by partition_id assigned_group: g rand_group`i' = runiform() if _n == 1 & partition_id == `i'
	egen rank_group`i' = rank(rand_group`i'), unique // rank groups within divisions
	by partition_id assigned_group: egen temp = max(rank_group`i')
	replace rank_group`i' = temp
	drop temp
}

/*assign first group in first randomly selected division to treatment*/ 
foreach i of numlist `selected_recovery_divisions'{
	/*assign to treatment*/
	replace treatment = 1 if rank_group`i' == 1
	
	/*assign to demand*/
	replace ranking_method = "DEMAND" if rank_group`i' == 1
}	
/*update treatment variable*/ 
replace treatment = 0 if missing(treatment) 

/*update treatment details variable*/
#delimit ; 
replace details_treatment = "control in year 1 & treatment in year 2" if treatment == 1 
	& details_treatment == "control in year 1" ; 
replace details_treatment = "excl. in year 1 & treatment in year 2" if treatment == 1 
	& details_treatment == "excluded in year 1" ; 
#delimit cr 
	
/*update numerical ranking method variable*/ 
replace ranking_method_num = 1 if ranking_method == "DEMAND"
replace ranking_method_num = 2 if ranking_method == "RECOVERY" 

/*checks*/ 
assert !missing(ranking_method) if treatment == 1
assert !missing(ranking_method_num) if treatment == 1 

levelsof assigned_group if treatment == 1, local(treated_groups)
local num_treat : word count `treated_groups' 
assert `num_treat' == 7 // 7 treated groups

levelsof assigned_group if ranking_method == "RECOVERY", local(recovery_groups)
local num_recovery : word count `recovery_groups'
assert `num_recovery' == 4 // 4 recovery groups

levelsof assigned_group if ranking_method == "DEMAND", local(demand_groups)
local num_demand : word count `demand_groups'
assert `num_demand' == 3 // 3 demand groups 

********************************************************************************
*3. Save files and display 

/*save files*/ 
tempfile control_groups_y2_rand_`m'
save `control_groups_y2_rand_`m''

}

**************************************************************************************************
*Checks
**************************************************************************************************

use `Lahore_1', clear
keep circle_id treatment
rename treatment treatment2
merge 1:1 circle_id using `Lahore_2'
tab treatment treatment2, m

use `Otherdiv_1', clear
keep circle_id treatment
rename treatment treatment2
merge 1:1 circle_id using `Otherdiv_2'
tab treatment treatment2, m

use `treated_groups_y2_rand_1', clear
keep circle_id treatment
rename treatment treatment2
merge 1:1 circle_id using `treated_groups_y2_rand_2'
tab treatment treatment2

// AT SOME POINT CREATE ANOTHER DO FILE THAT USES THE RIGHT SEEDS AND THIS DO FILE AND CHECK YOU
// GET THE SAME TREATMENT (SHOULD BE PERFECT MATCH) -- done separately -- all OK

**************************************************************************************************
*Consolidate RAND FILES
**************************************************************************************************

** Each Y1 iteration with its corresponding Y2 treatment assignment

forvalues m=1/`num' {

*Year 1

use `Lahore_`m'', clear
append using `Otherdiv_`m''

drop treatment
gen treatment = ranking_method != ""
gen REV_sel = ranking_method == "RECOVERY"
gen DEM_sel = ranking_method == "DEMAND"
replace group = 3 if partition_id == 10 & treatment == 1
egen group_id = group(partition_id group)
decode partition_id, generate(partition)
gen temp = " "
egen group_name = concat(partition temp group)
drop temp partition
drop group

tab treatment
keep circle_id treatment group_id  REV_sel DEM_sel
rename (group_id treatment REV_sel DEM_sel) (group_id_`m' treatment_y1_`m' REV_sel_y1_`m' DEM_sel_y1_`m')
tempfile y1_`m'
save `y1_`m''

*Year 2

**Load 10 Lahore Pilot group from Year 1
use `lahore_pilot'
keep if treatment == "PILOT GROUP"
gen circle_type = "Control"
drop treatment
gen treatment=0 // checkedtab t
*keep partition_id division_name group circle_id circle_name circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile lhr_pilot
sa `lhr_pilot'

use `multan_pilot'
keep if treatment == "PILOT GROUP"
gen circle_type = "Control"
drop treatment
gen treatment=0 // checked
*keep partition_id division_name group circle_id circle_name circle_type stratum_id
*keep partition_id division_name group circle_id circle_name circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile mt_pilot
sa `mt_pilot'

u `control_groups_y2_rand_`m'', clear
drop if treatment==1
gen circle_type = "Control"
*drop treatment
*keep partition_id division_name group circle_id circle_name circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile control_`m'
sa `control_`m''

* Adding 72 Non-Continuing circles to control
u `treated_groups_y2_rand_`m''
drop if treatment==1
gen circle_type = "Control"
*drop treatment
*keep partition_id division_name group circle_id circle_name circle_type stratum_id
gen new = 0
gen continuing = 0
tempfile non_cont_`m'
sa `non_cont_`m''

*THIS IS EXTRA: PREPARE DATASET W TREATMENT CIRCLES, THAT IS EQUIVALENT TO DATASET "140830 Treatment for Year 2"

u `control_groups_y2_rand_`m'', clear
drop if treatment==0
tempfile treatment1_`m'
save `treatment1_`m''
u `treated_groups_y2_rand_`m''
drop if treatment==0
tempfile treatment2_`m'
save `treatment2_`m''
append using `treatment1_`m''
tempfile treatment_for_year_2_`m'
save `treatment_for_year_2_`m''

* Add treatment circles to list
u `treatment_for_year_2_`m'', clear
gen circle_type = "Treatment"
*drop treatment
*keep partition_id division_name group circle_id circle_name circle_type ranking_method stratum_id details_treatment
gen new = details_treatment == "New"
gen continuing = details_treatment == "Continuing"
drop details_treatment
ren ranking_method scheme
gen DEM_sel = scheme == "DEMAND"
gen REV_sel = scheme == "RECOVERY"

append using `lhr_pilot'
append using `mt_pilot'
append using `control_`m''
append using `non_cont_`m''

tab treatment
replace DEM_sel=0 if mi(DEM_sel)
replace REV_sel=0 if mi(REV_sel)
keep circle_id treatment  DEM_sel REV_sel
*rename assigned_group group_id
rename (treatment DEM_sel REV_sel) (treatment_y2_`m' DEM_sel_y2_`m' REV_sel_y2_`m')
tempfile y2_`m'
save `y2_`m''

merge 1:1 circle_id  using `y1_`m'', assert(1 3) nogen

compress
tempfile iter_`m'
save `iter_`m''

}

** All iterations in same dataset // ideas for others?

use `iter_1', clear
forvalues m=2/`num' {
merge 1:1 circle_id using `iter_`m'', assert(3) nogen

}

}

save "../../TP Analysis\Coded Data/RI/rand_code_iter.dta", replace
