clear all
version 13
cap cd "$PAKTAX2_RANDOMIZATION"

********************************************************************************

**************************************************************************************************
***PREVIOUSLY EXCLUDED DIVISIONS
**************************************************************************************************

*1. Create sample for previously excluded divisions
use "Output/Year 1/140804 New Groups Ballot.dta", clear
assert inlist(partition_id, 2, 6, 9) // Confirm only DG Khan, Lahore C and Sahiwal 

qui count 
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  
assert stratum_id != .  

**************************************************************************************************

*2. Allocate circles to groups for previously excluded divisions
sort stratum_id circle_id 
**Select seed for main ballot 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

sort stratum_id circle_id 
g rand1 = runiform()	
by stratum_id: egen rank1 = rank(rand1), unique // rank1 within strata 
by stratum_id: egen count1 = count(rand1)

**Allocate circles into groups by stratified randomization. 
**First figure out the number of groups we need. 
**Ideal group size is 10 circles.  We get as close as possible to this.  

*Preparing for allocation 
g num_groups = floor(number_circles/10) 
g test1 = abs(number_circles/num_groups - 10)
g test2 = abs(number_circles/(num_groups + 1) - 10) 

levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ test1 if partition_id == `i', d
	local test1 `r(mean)'
	summ test2 if partition_id == `i', d
	local test2 `r(mean)'
	
	if (`test1' > `test2') { // if adding a group brings average closer to 10, then add a group  
		replace num_groups = num_groups + 1 if partition_id == `i'
	}
}

g group = .  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	count if partition_id == `i'
	local num_circles = `r(N)'
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	local per_group = floor(`num_circles'/`num_groups')
	local per_bin = floor(`per_group'/3) 

	forvalues g = 1(1)`num_groups'{
		#delimit ; 
		replace group = `g' if rank1 >= `per_bin' *(`g'-1) + 1 
			& rank1 <= `per_bin' *`g' & partition_id == `i' ; 
		#delimit cr 
	}
}

**Now deal with the residual circles.  
levelsof partition_id, local(partitions)
foreach i of numlist `partitions'{
	summ num_groups if partition_id == `i', d
	local num_groups `r(mean)' 
	
	**Randomly rank strata
	sort stratum_id circle_id
	by stratum_id: g temprand1 = runiform() if _n == 1 & partition_id == `i'
	egen strata_rank = rank(temprand1), unique 
	by stratum_id: egen temp = max(strata_rank) 
	replace strata_rank = temp 
	drop temp 

	**Randomly rank group
	sort partition_id group circle_id
	by partition_id group: g temprand2 = runiform() if _n == 1 & group != . & partition_id == `i'
	egen group_rank = rank(temprand2), unique   
	by partition_id group: egen temp = max(group_rank) 
	replace group_rank = temp 
	drop temp 
	
	summ strata_rank if partition_id == `i', d
	local strata_max = `r(max)' 
	local grouprank_counter = 1 

	forvalues s = 1(1)`strata_max'{
		count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	
		while `remaining_circles' > 0 {
			summ rank1 if strata_rank == `s' & group == . & partition_id == `i', d
			local min_rank = `r(min)' 
			summ group if group_rank == `grouprank_counter' & partition_id == `i', d
			local group = `r(min)'  
			replace group = `group' if rank1 == `min_rank' & strata_rank == `s' & partition_id == `i'

			local grouprank_counter = `grouprank_counter' + 1 
			if `grouprank_counter' > `num_groups' {
				local grouprank_counter = 1 		
			}	
		
			count if group == . & strata_rank == `s' & partition_id == `i' // number of remaining circles in randomly selected strata
			local remaining_circles = `r(N)' 
		}
		count if group == . & strata_rank == `s' & partition_id == `i' 
		assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
	}

	drop temprand* strata_rank group_rank
}

count if group == . 
assert `r(N)' == 0 // make sure no circles are without a group allocation
save "Output/Year 2/140805 New Groups Main Randomization $SEEDINPUT", replace

*************************************************************************************************
***PREVIOUSLY EXCLUDED CIRCLES
**************************************************************************************************

*3. Create sample for previously excluded circles
use "Output/Year 1/140804 Excluded Circles Ballot.dta", clear
qui count
local main_total_obs `r(N)'

*Number of circles in partition
bys partition_id: egen number_circles = count(circle_id)  
assert stratum_id != .  

**************************************************************************************************

*4. Allocate previously excluded circles to groups (SARGHODA) 
/*Set seed again*/ 
sort stratum_id circle_id 
set seed $SEEDINPUT
set sortseed $SEEDINPUT

**Allocate circles into groups: 

**First, start with Sarghoda (partition_id == 10):
**Since there is only 1 control group, we have to create 2 new groups: 
sort stratum_id circle_id 
g rand1 = runiform()	
by stratum_id: egen rank1 = rank(rand1), unique // rank1 within strata 
by stratum_id: egen count1 = count(rand1)

*Preparing for allocation 
replace group = . if partition_id == 10 // remove previous group assignment
g num_groups = 2 if partition_id == 10 
local num_groups 2 

count if partition_id == 10
local num_circles = `r(N)'
	
local per_group = floor(`num_circles'/`num_groups')
local per_bin = floor(`per_group'/3) 

forvalues g = 1(1)`num_groups'{
	#delimit ; 
	replace group = `g' if rank1 >= `per_bin' * (`g'-1) + 1 
		& rank1 <= `per_bin' *`g' & partition_id == 10; 
	#delimit cr 
}

**Now deal with the residual circles.  
summ num_groups if partition_id == 10, d
local num_groups `r(mean)' 
	
**Randomly rank strata
sort stratum_id circle_id
by stratum_id: g temprand1 = runiform() if _n == 1 & partition_id == 10
egen strata_rank = rank(temprand1), unique 
by stratum_id: egen temp = max(strata_rank) 
replace strata_rank = temp 
drop temp 

**Randomly rank group
sort partition_id group circle_id
by partition_id group: g temprand2 = runiform() if _n == 1 & group != . & partition_id == 10
egen group_rank = rank(temprand2), unique   
by partition_id group: egen temp = max(group_rank) 
replace group_rank = temp 
drop temp 
	
summ strata_rank if partition_id == 10, d
local strata_max = `r(max)' 
local grouprank_counter = 1 

forvalues s = 1(1)`strata_max'{
	count if group == . & strata_rank == `s' & partition_id == 10 // number of remaining circles in randomly selected strata
	local remaining_circles = `r(N)' 
	
	while `remaining_circles' > 0 {
		summ rank1 if strata_rank == `s' & group == . & partition_id == 10, d
		local min_rank = `r(min)' 
		summ group if group_rank == `grouprank_counter' & partition_id == 10, d
		local group = `r(min)'  
		replace group = `group' if rank1 == `min_rank' & strata_rank == `s' & partition_id == 10

		local grouprank_counter = `grouprank_counter' + 1 
		if `grouprank_counter' > `num_groups' {
			local grouprank_counter = 1 		
		}	
		
		count if group == . & strata_rank == `s' & partition_id == 10 // number of remaining circles in randomly selected strata
		local remaining_circles = `r(N)' 
	}
	count if group == . & strata_rank == `s' & partition_id == 10 
	assert `r(N)' == 0  // make sure no remaining circles before moving on to next strata
}
drop rank1* rand1* temprand* strata_rank group_rank

count if group == . & partition_id == 10 
assert `r(N)' == 0 // make sure no circles are without a group allocation

**************************************************************************************************
*5. Allocate previously excluded circles to groups (REMAINING DIVISIONS) 
sort partition_id group circle_id 
levelsof partition_id if missing(group), local(partitions) // partitions with excluded circles
foreach i of numlist `partitions'{
	
	levelsof stratum_id if missing(group) & partition_id == `i', local(strata) // strata with excluded circles 
	foreach s of numlist `strata'{
		sort partition_id group	circle_id 
		by partition_id group: egen num_circles_strata = total(stratum_id == `s') ///
			if group != .  & partition_id == `i' // determine number of circles in that strata in each group
		
		**Randomly rank group
		g group_rank = . 
		local corrector = 0 // corrector for generating one group rank 
		levelsof num_circles_strata, local(num_circles) 
		foreach n of numlist `num_circles'{
			sort partition_id group circle_id 
			by partition_id group: g rand2_`n' = runiform() /// 
				if _n == 1 & group != . & num_circles_strata == `n' & partition_id == `i'
			egen temp1 = rank(rand2_`n'), unique   
			by partition_id group: egen temp2 = max(temp1) 
			replace group_rank = temp2 + `corrector' if missing(group_rank) 
			drop temp1 temp2  
		
			summ group_rank
			local corrector `r(max)' 
		}
		local grouprank_counter = 1 
		
		**Randomly rank excluded circles
		sort partition_id group circle_id
		g rand3 = runiform() if missing(group) & stratum_id == `s' & partition_id == `i'
		egen circle_rank = rank(rand3), unique   
		local circlerank_counter = 1 
	
		**Assign circles to groups
		count if group == . & stratum_id == `s' & partition_id == `i' // number of excluded circles in that strata & partition 
		local remaining_circles = `r(N)' 
			
		while `remaining_circles' > 0 {
			**Assign circles to groups 
			summ group if group_rank == `grouprank_counter' & partition_id == `i', d
			local group = `r(min)'  
			
			replace group = `group' if circle_rank == `circlerank_counter' & missing(group) 
			local grouprank_counter = `grouprank_counter' + 1 
			local circlerank_counter = `circlerank_counter' + 1 

			count if group == . & stratum_id == `s' & partition_id == `i' // number of excluded circles in that strata
			local remaining_circles = `r(N)' 
		}
		
		drop group_rank* circle_rank* rand* num_circles_strata
	}
}

assert !missing(group) // confirm no circle without a group 
save "Output/Year 2/140805 Excluded Circles Main Randomization $SEEDINPUT", replace

**********************************************************************

*6. Save data, outsheet groups, and display groups of circles
use "Output/Year 2/140805 New Groups Main Randomization $SEEDINPUT", clear
append using "Output/Year 2/140805 Excluded Circles Main Randomization $SEEDINPUT"

sort group division_name circle_id
save "Output/Year 2/140805 Year 1 Control Groups Main Randomization $SEEDINPUT", replace
