/*

Inspectors happiness 2.0

Approach 1: use "Y1 Movement Dummies only"
	
*/


******************************************************************************
* Data setup
******************************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare input file paths
local movements_file = 			"Coded Data/Y1 Movement Dummies"
local crosswalk = 				"../Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv"
local base_prefs = 				"Coded Data/Cleaned baseline preferences.dta"
local hr_q3_2015 =				"../Data/Cleaned Data/HR/FY 2015 Inspector HR.dta"

******************************************************************************
* Data setup
******************************************************************************

* 1 Preference data for treated inspectors

	use "Coded Data/Preferences data - treatment", clear
	label var rank_perf "Y1 Performance rank"
	drop _m
	keep hr_id group_id base_current_ranking base_new_ranking any_move rank_perf norm_change_ranking_base norm_change_ranking_y1 y1_current_ranking
	tempfile treatment
	save `treatment'

* 2 Y1 treatment assignment
	
	use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
	keep if qtr==4
	keep circle_id treatment
	tempfile y1treatment
	save `y1treatment'
	
* 3  Crosswalking
	
	* Load list of pilot circles
	use "../Data/Randomization/output/Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta", clear
	append using "../Data/Randomization/output/Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta"
	keep circle_id
	isid circle_id
	tempfile pilot_circles
	sa `pilot_circles'

	use "Coded Data/Cleaned baseline preferences", clear
	merge m:1 circle_id using `pilot_circles' // Remove pilot circles
	keep if _m == 1
	drop _m
	ren hr_id own_hr_id
	drop if mi(own_hr_id)
	tempfile base_preferences
	save `base_preferences'

	* Need to crosswalk transfer table circle IDs
	insheet using "../Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
	keep ballot_circle_id
	duplicates drop
	drop if mi(ballot_circle_id)
	tempfile ballot_circle_ids
	sa `ballot_circle_ids', replace

* 4 Transfers for inspectors in the control group

	use "Coded Data/Y1 Movement Dummies", clear 
	merge 1:1 circle_id using `y1treatment'
	drop treatment_y1
	drop if treatment==.
	drop if treatment==1
	drop if _m==2 // where are these two coming from?
	assert _m==3
	drop _m
	rename treatment treatment_y1
	rename y2q3_circle_id1 new_circle_id
	tempfile transfer_table
	sa `transfer_table', replace

******************************************************************************
* Data cleaning
******************************************************************************

* 1 Adding rank to new and current circle

	* Use baseline preferences
	use `base_preferences', clear
	keep partition_name group own_hr_id circle_id ranking
	rename own_hr_id hr_id
	duplicates drop

	* Calculate u1

	keep hr_id circle_id ranking 
	ren ranking base_current_ranking
	merge 1:1 circle_id hr_id using `transfer_table', assert(1 3) nogen keep(3)
	tabmiss base_current_ranking
	tempfile pref_analysis_data
	sa `pref_analysis_data'

	*Get ranking information for inspectors who moved to a circle within their group

	use `transfer_table', clear
	keep if !mi(new_circle_id) & any_move==1
	
	preserve
	use `base_preferences', clear
	keep partition_name group own_hr_id circle_id ranking
	duplicates drop
	drop if mi(ranking)
	rename own_hr_id hr_id
	rename circle_id new_circle_id
	rename ranking base_new_ranking
	save `base_preferences', replace
	restore
	merge 1:1 new_circle_id partition_name group hr_id new_circle_id using `base_preferences', keep(3) nogen

	merge 1:1 circle_id partition_name group hr_id using `pref_analysis_data', nogen assert(2 3)
	keep circle_id new_circle_id partition_name group hr_id base_current_ranking base_new_ranking

	* Generate analysis variables

	assert !mi(circle_id)
	gen any_move =					new_circle_id != circle_id	 
	gen move_up_base = 				base_new_ranking < base_current_ranking
	gen move_down_base = 			base_new_ranking > base_current_ranking		if !mi(base_new_ranking) & !mi(base_current_ranking)
	gen own_circle_favorite_base_r1 = 	(base_current_ranking == 1 & !mi(base_current_ranking)) 
	gen own_circle_favorite_base_r2 = 	(base_current_ranking == 1 & !mi(base_current_ranking)) | (base_current_ranking == 2 & !mi(base_current_ranking))
	gen own_circle_favorite_base_r3 = 	(base_current_ranking == 1 & !mi(base_current_ranking)) | (base_current_ranking == 2 & !mi(base_current_ranking)) | (base_current_ranking == 3 & !mi(base_current_ranking))
	gen change_ranking_base = base_new_ranking - base_current_ranking if !mi(base_new_ranking) & !mi(base_current_ranking)
	sa `pref_analysis_data', replace
	
* 2 Ranks for control groups based on Demand and Recovery

	use "Coded Data/FY14 Q4 DEMAND Ranks control inspectors", clear
	merge 1:1 hr_id using "Coded Data/FY14 Q4 RECOVERY Ranks control inspectors", assert(3) nogen
	tempfile y1_performance
	save `y1_performance'
	
* 3 Getting all the data at the inspector level

	use `pref_analysis_data', clear
	merge m:1 hr_id using "`y1_performance'", nogen // All inspector's performanc plus their treatment statuss
	gen treatment_y1=0 
	assert !mi(circle_id)	
	forvalues i=1/2 {
	local name: word `i' of "dem" "rec" 
	local label: word `i' of "Demand" "Recovery"
	gsort group_id -final_score_`name'
	by group_id: gen rank_perf_`name' = _n if final_score_`name'!=.
	summ rank_perf_`name'
	replace rank_perf_`name'=(r(max)-rank_perf_`name')/(r(max)-r(min))
	}
	
	tempfile control
	save `control'	
	assert !mi(treatment_y1)
	append using `treatment'	
	replace treatment_y1=1 if mi(treatment_y1)
	
	* Create variables w missings
	label var treatment_y1 "Y1 Treatment"
	label var rank_perf "Y1 Rank"

	* Final vars
	bys group_id: gen num_circles=_N
	gen num1=num_circles
	gen num2=num_circles-1
	gen num3=num_circles-2
	replace own_circle_favorite_base_r1=1 if base_current_ranking == 1  & treatment_y1==1
	replace own_circle_favorite_base_r1=0 if base_current_ranking != 1  & treatment_y1==1
	replace own_circle_favorite_base_r2=1 if (base_current_ranking == 1  | base_current_ranking == 2 ) & treatment_y1==1
	replace own_circle_favorite_base_r2=0 if mi(own_circle_favorite_base_r2)
	replace own_circle_favorite_base_r1=0 if base_current_ranking != 1 & treatment_y1==1
	tab own_circle_favorite_base_r1 treatment_y1
	tab own_circle_favorite_base_r2 treatment_y1
	tabmiss rank_perf
	tempfile analysis_data
	sa `analysis_data'

******************************************************************************
* 2. Table w analysis 1 and 2
******************************************************************************

use `analysis_data', clear

gen stay=any_move==0

preserve
keep if treatment_y1==1
eststo change_bp_fe 	: 	areg norm_change_ranking_base rank_perf ,  absorb(group_id) vce(cluster group_id)
eststo change_bp_fe 	: 	areg norm_change_ranking_base rank_perf ,  absorb(group_id) vce(cluster group_id)
eststo change_y1p_fe 	: 	areg norm_change_ranking_y1 rank_perf ,  absorb(group_id) vce(cluster group_id)
eststo any1_treat_fe_base 	: 	areg stay rank_perf if own_circle_favorite_base_r1==1 & treatment_y1==1,  absorb(group_id) vce(cluster group_id)
eststo any2_treat_fe_base 	: 	areg stay rank_perf if own_circle_favorite_base_r2==1 & treatment_y1==1,  absorb(group_id) vce(cluster group_id)
gen own_circle_favorite_y1_r1=y1_current_ranking == 1 
gen own_circle_favorite_y1_r2=(y1_current_ranking == 1  | y1_current_ranking == 2 ) 
eststo any1_treat_fe_y1 	: 	areg stay rank_perf if own_circle_favorite_y1_r1==1 & treatment_y1==1,  absorb(group_id) vce(cluster group_id)
eststo any2_treat_fe_y1 	: 	areg stay rank_perf if own_circle_favorite_y1_r2==1 & treatment_y1==1,  absorb(group_id) vce(cluster group_id)
restore

*Average 

preserve 
replace rank_perf=(rank_perf_dem+rank_perf_rec)/2 if treatment_y1==0
eststo any1_bp_av_fe 	: 		areg stay treatment_y1##c.rank_perf  if own_circle_favorite_base_r1==1, a(group_id) vce(cluster group_id)
eststo any2_bp_av_fe 	: 		areg stay treatment_y1##c.rank_perf if own_circle_favorite_base_r2==1, a(group_id) vce(cluster group_id)
restore 

*Half half

set seed 21318
preserve 
keep if treatment_y1==0
keep group_id
duplicates drop
gen rand=runiform()
sort rand
gen rec=_n<=_N/2
tempfile rec
save `rec'
restore
merge m:1 group_id using `rec', assert(1 3)
replace rank_perf=rank_rec if rec==1
replace rank_perf=rank_dem if rec==0
eststo any1_bp_half_fe 	: 		areg stay treatment_y1##c.rank_perf  if own_circle_favorite_base_r1==1, a(group_id) vce(cluster group_id)
eststo any2_bp_half_fe 	: 		areg stay treatment_y1##c.rank_perf if own_circle_favorite_base_r2==1, a(group_id) vce(cluster group_id)

local file = "happiness_paper_fe"

# delimit ;
esttab change_bp_fe change_y1p_fe any1_treat_fe_base  any1_treat_fe_y1 any2_treat_fe_base any2_treat_fe_y1 any1_bp_half_fe  any2_bp_half_fe 
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	keep(rank_perf 1.treatment_y1#c.rank_perf)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	nostar
	coeflabels(1.treatment_y1#c.rank_perf "Y1 Treatment * Y1 Rank")
	mtitles("\shortstack{Base prefs\\}" "\shortstack{Y1 prefs\\}" "\shortstack{Top choice\\Base prefs}" "\shortstack{Top choice\\Y1 prefs}" "\shortstack{Top two choices\\Base prefs}" "\shortstack{Top two choices\\Y1 prefs}" "\shortstack{Top choice\\Base prefs}" "\shortstack{Top two choices\\Base prefs}")
	
	order(rank_perf int_treat_rank)
	
		mgroups("Change in rank" "Stay in status quo",
	pattern(1 0 1 0 0 0 0 0 0 1
	)
	
	prefix(\multicolumn{@span}{c}{)
	suffix(}) span erepeat(\cmidrule(lr){@span})
)		

	stats(N,
		labels(
			"N"
		)	
		fmt(
			"%12.0f"
		)
	)			
	
	label // Use Variable Labels
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr


** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Columns 1 and 2 present OLS regressions of the change in an inspector's preference rank on their performance-based group rank."
file write tablenote " Columns 3 to 8 show the results from regressing the probability of staying in a top choice circle on inspector's performance-based group rank."
file write tablenote " The sample in Columns 3 to 6 consists of Y1 treated inspectors. In Columns 7 and 8 the sample comprises both treated and control inspectors."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/")  
