/*
Create histograms on returns to effort for different simulation parameters

Author(s):
	Ismail Khan (2015-2017)
	
Date created:
	Dec 10, 2015
		
*/

******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
pause on
set graphics on
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare number of iterations we would like to display
local num_iter = 			10000 // calling this 10,000 so that don't have to change the reference

* Declare folders
local sim_folder = 				"output\Transfer simulations"
local output_folder = 			"output/Paper/graphs"
local data_folder = 			"Coded Data"

* Declare input file paths
local sim_zerom_zerok = 		"`sim_folder'/sim_i`num_iter'_zerom_zerok.csv"
local sim_y1m_zerok = 			"`sim_folder'/sim_i`num_iter'_y1m_zerok.csv"
local sim_zerom_fullk = 		"`sim_folder'/sim_i`num_iter'_zerom_fullk.csv"
local sim_y1m_fullk = 			"`sim_folder'/sim_i`num_iter'_y1m_fullk.csv"
local sim_zerom_randk = 		"`sim_folder'/sim_i`num_iter'_zerom_randk.csv"
local sim_y1m_randk = 			"`sim_folder'/sim_i`num_iter'_y1m_randk.csv"

******************************************************************************
* 1. Load and prep simulation data
******************************************************************************

* For all possible number of iterations
foreach k in zerok fullk randk {
	foreach m in zerom y1m {

		* Load simulation data and rename variables
		insheet using "`sim_`m'_`k''", comma clear
		ren v1 group_id
		ren v2 hr_id
		ren v3 dEu1dy
		ren v4 dEu2dy
		ren v5 dEu3dy

		tempfile sim_`m'_`k'
		sa `sim_`m'_`k''
	}
}

******************************************************************************
* 2. Draw histograms of distribution of return to effect (across inspectors)
******************************************************************************

set scheme s1color

use `sim_y1m_fullk', clear
histogram dEu1dy, xlabel(0(0.5)2.0) ylabel(0(1)3.5)
graph export "`output_folder'/histogram_u1_y1m_fullk_i10000_long_axis.pdf", replace

* For all possible number of iterations

forvalues i=1/2 {
local k: word `i' of zerok fullk
local k_t: word `i' of "Identical P" "Full knowledge of P"

forvalues j=1/2 {
local m: word `j' of zerom y1m 
local m_t: word `j' of " & No knowledge of y" " & Full knowledge of y"

	* Draw histogram for each utility function
	use `sim_`m'_`k'', clear
	forval u = 1/1 {
		preserve
		rename dEu`u'dy dEudy
		histogram dEudy, xlabel(0(0.5)1.5) ylabel(0(1)3.5) title("`k_t'`m_t'")
		graph export "`output_folder'/histogram_u`u'_`m'_`k'_i10000.pdf", replace
		restore
	}
}
}

local k = "randk"
forvalues j=1/2 {
local m: word `j' of zerom y1m 
local m_t: word `j' of " & No knowledge of y" " & Full knowledge of y"

	* Draw histogram for each utility function
	use `sim_`m'_`k'', clear
	forval u = 1/1 {
		preserve
		rename dEu`u'dy dEudy
		histogram dEudy, xlabel(0(0.5)1.5) ylabel(0(1)3.5) title("Random P`m_t'")
		graph export "`output_folder'/histogram_u`u'_`m'_`k'_i10000.pdf", replace
		restore
	}
}


* Overwrite zerom & zerok histogram for u1

use `sim_zerom_zerok', clear
rename dEu1dy dEudy
histogram dEudy, bin(1) xlabel(0(0.5)1.5) title("Identical P & No knowledge of y")
graph export "`output_folder'/histogram_u1_zerom_zerok_i10000.pdf", replace
