/*

Create histograms on eq effort
		
*/

******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
pause on
set graphics on
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare folders
local sim_folder = 				"output\Transfer simulations"
local output_folder = 			"output/Paper/graphs"
local data_folder = 			"Coded Data"

* Declare input file paths
local sim_y1m_zerok = 			"`sim_folder'/eqeffort_avg_100iter_y1m_zerok.csv"
local sim_zerom_fullk = 		"`sim_folder'/eqeffort_avg_100iter_zerom_fullk.csv"
local sim_y1m_fullk = 			"`sim_folder'/eqeffort_avg_100iter_y1m_fullk.csv"
local sim_y1m_randk = 			"`sim_folder'/eqeffort_avg_100iter_y1m_randk.csv"

******************************************************************************
* 1. Load and prep simulation data
******************************************************************************

* For all possible number of iterations
foreach k in y1m_zerok zerom_fullk y1m_fullk y1m_randk  {
	insheet using "`sim_`k''", comma clear
	ren mean_eqeffort eq_effort

	tempfile sim_`k'
	sa `sim_`k''
}

******************************************************************************
* 2. Draw histograms of distribution of return to effect (across inspectors)
******************************************************************************

* For all kn assumptions, draw graph

set scheme s1color

forvalues i=1/4 {
local k: word `i' of y1m_zerok zerom_fullk y1m_fullk y1m_randk 
local k_t: word `i' of "Identical P & Full knowledge of y" "Full knowledge of P & No knowledge of y" "Full knowledge of P & Full knowledge of y" "Random P & Full knowledge of y" 
	
		* Draw histogram for each utility function
		use `sim_`k'', clear
		forval u = 1/1 {
			histogram eq_effort, xlabel(0(0.02)0.1) title("`k_t'")
			graph export "`output_folder'/histogram_u`u'_`k'_eqeffort_avg.pdf", replace
			}

}
